@@ -20,11 +20,13 @@
 
 #include "framestackmodel.h"
 
+#include <QFileInfo>
 #include <QIcon>
 #include <QMimeType>
 #include <QMimeDatabase>
 
 #include <KLocalizedString>
+#include <KColorScheme>
 
 #include "../../interfaces/icore.h"
 #include "../../interfaces/idebugcontroller.h"
@@ -34,12 +36,39 @@
 
 namespace KDevelop {
 
+class FrameStackModelPrivate
+{
+public:
+    FrameStackModelPrivate(FrameStackModel* q) : q(q) {}
+
+    void update();
+
+    QModelIndex indexForThreadNumber(int threadNumber);
+
+    FrameStackModel* q;
+
+    int m_currentThread = -1;
+    int m_currentFrame = -1;
+
+    int m_crashedThreadIndex = -1;
+
+    // used to count how often a user has scrolled down and more frames needed to be fetched;
+    // this way, the number of frames fetched in each chunk can be increased if the user wants
+    // to scroll far
+    int m_subsequentFrameFetchOperations = 0;
+    bool m_updateCurrentFrameOnNextFetch = false;
+
+    QList<FrameStackModel::ThreadItem> m_threads;
+    QHash<int, QList<FrameStackModel::FrameItem> > m_frames;
+    QHash<int, bool> m_hasMoreFrames;
+
+    // Caches
+    QHash<QString, bool> m_fileExistsCache;
+};
+
 FrameStackModel::FrameStackModel(IDebugSession *session)
     : IFrameStackModel(session)
-    , m_currentThread(-1)
-    , m_currentFrame(-1)
-    , m_subsequentFrameFetchOperations(0)
-    , m_updateCurrentFrameOnNextFetch(false)
+    , d(new FrameStackModelPrivate(this))
 {
     connect(session, &IDebugSession::stateChanged, this, &FrameStackModel::stateChanged);
 }
@@ -52,25 +81,25 @@ void FrameStackModel::setThreads(const QList<ThreadItem> &threads)
 {
     qCDebug(DEBUGGER) << threads.count();
 
-    if (!m_threads.isEmpty()) {
-        beginRemoveRows(QModelIndex(), 0, m_threads.count()-1);
-        m_threads.clear();
+    if (!d->m_threads.isEmpty()) {
+        beginRemoveRows(QModelIndex(), 0, d->m_threads.count()-1);
+        d->m_threads.clear();
         endRemoveRows();
     }
 
     if (!threads.isEmpty()) {
         beginInsertRows(QModelIndex(), 0, threads.count()-1);
-        m_threads = threads;
+        d->m_threads = threads;
         endInsertRows();
     }
 }
 
-QModelIndex FrameStackModel::indexForThreadNumber(int threadNumber)
+QModelIndex FrameStackModelPrivate::indexForThreadNumber(int threadNumber)
 {
     int i=0;
-    foreach (const ThreadItem &t, m_threads) {
+    foreach (const auto &t, m_threads) {
         if (t.nr == threadNumber) {
-            return index(i, 0);
+            return q->index(i, 0);
         }
         i++;
     }
@@ -79,80 +108,91 @@ QModelIndex FrameStackModel::indexForThreadNumber(int threadNumber)
 
 void FrameStackModel::setFrames(int threadNumber, QList<FrameItem> frames)
 {
-    QModelIndex threadIndex = indexForThreadNumber(threadNumber);
+    QModelIndex threadIndex = d->indexForThreadNumber(threadNumber);
     Q_ASSERT(threadIndex.isValid());
 
-    if (!m_frames[threadNumber].isEmpty()) {
-        beginRemoveRows(threadIndex, 0, m_frames[threadNumber].count()-1);
-        m_frames[threadNumber].clear();
+    if (!d->m_frames[threadNumber].isEmpty()) {
+        beginRemoveRows(threadIndex, 0, d->m_frames[threadNumber].count()-1);
+        d->m_frames[threadNumber].clear();
         endRemoveRows();
     }
 
     if (!frames.isEmpty()) {
         beginInsertRows(threadIndex, 0, frames.count()-1);
-        m_frames[threadNumber] = frames;
+        d->m_frames[threadNumber] = frames;
         endInsertRows();
     }
 
-    if (m_currentThread == threadNumber && m_updateCurrentFrameOnNextFetch) {
-        m_currentFrame = 0;
-        m_updateCurrentFrameOnNextFetch = false;
+    if (d->m_currentThread == threadNumber && d->m_updateCurrentFrameOnNextFetch) {
+        d->m_currentFrame = 0;
+        d->m_updateCurrentFrameOnNextFetch = false;
     }
 
+    d->m_fileExistsCache.clear();
+
     session()->raiseEvent(IDebugSession::thread_or_frame_changed);
 
     // FIXME: Ugly hack. Apparently, when rows are added, the selection
     // in the view is cleared. Emit this so that some frame is still
     // selected.
-    emit currentFrameChanged(m_currentFrame);
+    emit currentFrameChanged(d->m_currentFrame);
 }
 
 void FrameStackModel::insertFrames(int threadNumber, const QList<FrameItem> &frames)
 {
-    QModelIndex threadIndex = indexForThreadNumber(threadNumber);
+    QModelIndex threadIndex = d->indexForThreadNumber(threadNumber);
     Q_ASSERT(threadIndex.isValid());
 
-    beginInsertRows(threadIndex, m_frames[threadNumber].count()-1,
-                    m_frames[threadNumber].count()+frames.count()-1);
-    m_frames[threadNumber] << frames;
+    beginInsertRows(threadIndex, d->m_frames[threadNumber].count()-1,
+                    d->m_frames[threadNumber].count()+frames.count()-1);
+    d->m_frames[threadNumber] << frames;
     endInsertRows();
 }
 
 void FrameStackModel::setHasMoreFrames(int threadNumber, bool hasMoreFrames)
 {
-    m_hasMoreFrames[threadNumber] = hasMoreFrames;
+    d->m_hasMoreFrames[threadNumber] = hasMoreFrames;
 }
 
 FrameStackModel::FrameItem FrameStackModel::frame(const QModelIndex& index)
 {
     Q_ASSERT(index.internalId());
-    Q_ASSERT(static_cast<quintptr>(m_threads.count()) >= index.internalId());
-    const ThreadItem &thread = m_threads.at(index.internalId()-1);
-    return m_frames[thread.nr].at(index.row());
+    Q_ASSERT(static_cast<quintptr>(d->m_threads.count()) >= index.internalId());
+    const ThreadItem &thread = d->m_threads.at(index.internalId()-1);
+    return d->m_frames[thread.nr].at(index.row());
 }
 
 QList<FrameStackModel::FrameItem> FrameStackModel::frames(int threadNumber) const
 {
-    return m_frames.value(threadNumber);
+    return d->m_frames.value(threadNumber);
 }
 
 QVariant FrameStackModel::data(const QModelIndex& index, int role) const
 {
     if (!index.internalId()) {
         //thread
-        if (m_threads.count() <= index.row()) return QVariant();
-        const ThreadItem &thread = m_threads.at(index.row());
+        if (d->m_threads.count() <= index.row()) return QVariant();
+        const ThreadItem &thread = d->m_threads.at(index.row());
         if (index.column() == 0) {
             if (role == Qt::DisplayRole) {
-                return i18nc("#thread-id at function-name or address", "#%1 at %2", thread.nr, thread.name);
+                if (thread.nr == d->m_crashedThreadIndex) {
+                    return i18nc("#thread-id at function-name or address", "#%1 at %2 (crashed)", thread.nr, thread.name);
+                } else {
+                    return i18nc("#thread-id at function-name or address", "#%1 at %2", thread.nr, thread.name);
+                }
+            } else if (role == Qt::TextColorRole) {
+                if (thread.nr == d->m_crashedThreadIndex) {
+                    KColorScheme scheme(QPalette::Active);
+                    return scheme.foreground(KColorScheme::NegativeText).color();
+                }
             }
         }
     } else {
         //frame
-        if (static_cast<quintptr>(m_threads.count()) < index.internalId()) return QVariant();
-        const ThreadItem &thread = m_threads.at(index.internalId()-1);
-        if (m_frames[thread.nr].count() <= index.row()) return QVariant();
-        const FrameItem &frame = m_frames[thread.nr].at(index.row());
+        if (static_cast<quintptr>(d->m_threads.count()) < index.internalId()) return QVariant();
+        const ThreadItem &thread = d->m_threads.at(index.internalId()-1);
+        if (d->m_frames[thread.nr].count() <= index.row()) return QVariant();
+        const FrameItem &frame = d->m_frames[thread.nr].at(index.row());
         if (index.column() == 0) {
             if (role == Qt::DisplayRole) {
                 return QVariant(QString::number(frame.nr));
@@ -172,6 +212,17 @@ QVariant FrameStackModel::data(const QModelIndex& index, int role) const
             } else if (role == Qt::DecorationRole) {
                 QMimeType mime = QMimeDatabase().mimeTypeForUrl(frame.file);
                 return QIcon::fromTheme(mime.iconName());
+            } else if (role == Qt::TextColorRole) {
+                const auto fileName = frame.file.toLocalFile();
+                auto cacheIt = d->m_fileExistsCache.find(fileName);
+                if (cacheIt == d->m_fileExistsCache.end()) {
+                    cacheIt = d->m_fileExistsCache.insert(fileName, QFileInfo::exists(fileName));
+                }
+                const bool fileExists = cacheIt.value();
+                if (!fileExists) {
+                    KColorScheme scheme(QPalette::Active);
+                    return scheme.foreground(KColorScheme::InactiveText).color();
+                }
             }
         }
     }
@@ -187,10 +238,10 @@ int FrameStackModel::columnCount(const QModelIndex& parent) const
 int FrameStackModel::rowCount(const QModelIndex& parent) const
 {
     if (!parent.isValid()) {
-        return m_threads.count();
+        return d->m_threads.count();
     } else if (!parent.internalId() && parent.column() == 0) {
-        if (parent.row() < m_threads.count()) {
-            return m_frames[m_threads.at(parent.row()).nr].count();
+        if (parent.row() < d->m_threads.count()) {
+            return d->m_frames[d->m_threads.at(parent.row()).nr].count();
         }
     }
     return 0;
@@ -210,7 +261,7 @@ QModelIndex FrameStackModel::index(int row, int column, const QModelIndex& paren
     if (parent.isValid()) {
         Q_ASSERT(!parent.internalId());
         Q_ASSERT(parent.column() == 0);
-        Q_ASSERT(parent.row() < m_threads.count());
+        Q_ASSERT(parent.row() < d->m_threads.count());
         return createIndex(row, column, parent.row()+1);
     } else {
         return createIndex(row, column);
@@ -235,22 +286,21 @@ QVariant FrameStackModel::headerData(int section, Qt::Orientation orientation, i
 void FrameStackModel::setCurrentThread(int threadNumber)
 {
     qCDebug(DEBUGGER) << threadNumber;
-    if (m_currentThread != threadNumber && threadNumber != -1) {
+    if (d->m_currentThread != threadNumber && threadNumber != -1) {
         // FIXME: this logic means that if we switch to thread 3 and
         // then to thread 2 and then to thread 3, we'll request frames
         // for thread 3 again, even if the program was not run in between
         // and therefore frames could not have changed.
-        m_currentFrame = 0; //set before fetchFrames else --frame argument would be wrong
-        m_updateCurrentFrameOnNextFetch = true;
+        d->m_currentFrame = 0; //set before fetchFrames else --frame argument would be wrong
+        d->m_updateCurrentFrameOnNextFetch = true;
         fetchFrames(threadNumber, 0, 20);
     }
-    if (threadNumber != m_currentThread) {
-        m_currentFrame = 0;
-        qCDebug(DEBUGGER) << "currentFrame" << m_currentFrame;
-        m_currentThread = threadNumber;
-        emit currentFrameChanged(m_currentFrame);
+    if (threadNumber != d->m_currentThread) {
+        d->m_currentFrame = 0;
+        d->m_currentThread = threadNumber;
+        emit currentFrameChanged(d->m_currentFrame);
     }
-    qCDebug(DEBUGGER) << "currentThread: " << m_currentThread << "currentFrame: " << m_currentFrame;
+    qCDebug(DEBUGGER) << "currentThread: " << d->m_currentThread << "currentFrame: " << d->m_currentFrame;
     emit currentThreadChanged(threadNumber);
     session()->raiseEvent(IDebugSession::thread_or_frame_changed);
 }
@@ -260,19 +310,28 @@ void FrameStackModel::setCurrentThread(const QModelIndex& index)
     Q_ASSERT(index.isValid());
     Q_ASSERT(!index.internalId());
     Q_ASSERT(index.column() == 0);
-    setCurrentThread(m_threads[index.row()].nr);
+    setCurrentThread(d->m_threads[index.row()].nr);
 }
 
+void FrameStackModel::setCrashedThreadIndex(int index)
+{
+    d->m_crashedThreadIndex = index;
+}
+
+int FrameStackModel::crashedThreadIndex() const
+{
+    return d->m_crashedThreadIndex;
+}
 
 int FrameStackModel::currentThread() const
 {
-    return m_currentThread;
+    return d->m_currentThread;
 }
 
 QModelIndex FrameStackModel::currentThreadIndex() const
 {
     int i = 0;
-    foreach (const ThreadItem &t, m_threads) {
+    foreach (const ThreadItem &t, d->m_threads) {
         if (t.nr == currentThread()) {
             return index(i, 0);
         }
@@ -283,32 +342,32 @@ QModelIndex FrameStackModel::currentThreadIndex() const
 
 int FrameStackModel::currentFrame() const
 {
-    return m_currentFrame;
+    return d->m_currentFrame;
 }
 
 QModelIndex FrameStackModel::currentFrameIndex() const
 {
     QModelIndex idx = currentThreadIndex();
-    return idx.child(m_currentFrame, 0);
+    return idx.child(d->m_currentFrame, 0);
 }
 
 void FrameStackModel::setCurrentFrame(int frame)
 {
     qCDebug(DEBUGGER) << frame;
-    if (frame != m_currentFrame)
+    if (frame != d->m_currentFrame)
     {
-        m_currentFrame = frame;
+        d->m_currentFrame = frame;
         session()->raiseEvent(IDebugSession::thread_or_frame_changed);
         emit currentFrameChanged(frame);
     }
 }
 
-void FrameStackModel::update()
+void FrameStackModelPrivate::update()
 {
     m_subsequentFrameFetchOperations = 0;
-    fetchThreads();
+    q->fetchThreads();
     if (m_currentThread != -1) {
-        fetchFrames(m_currentThread, 0, 20);
+        q->fetchFrames(m_currentThread, 0, 20);
     }
 }
 
@@ -317,7 +376,7 @@ void FrameStackModel::handleEvent(IDebugSession::event_t event)
     switch (event)
     {
     case IDebugSession::program_state_changed:
-        update();
+        d->update();
         break;
 
     default:
@@ -329,7 +388,7 @@ void FrameStackModel::stateChanged(IDebugSession::DebuggerState state)
 {
     if (state == IDebugSession::PausedState) {
         setCurrentFrame(-1);
-        m_updateCurrentFrameOnNextFetch = true;
+        d->m_updateCurrentFrameOnNextFetch = true;
     } else if (state == IDebugSession::EndedState || state == IDebugSession::NotStartedState) {
         setThreads(QList<FrameStackModel::ThreadItem>());
     }
@@ -339,15 +398,14 @@ void FrameStackModel::stateChanged(IDebugSession::DebuggerState state)
 // an arbitrary thread, without making it current.
 void FrameStackModel::fetchMoreFrames()
 {
-    m_subsequentFrameFetchOperations += 1;
-    const int fetch = 20 * m_subsequentFrameFetchOperations * m_subsequentFrameFetchOperations;
-    if (m_currentThread != -1 && m_hasMoreFrames[m_currentThread]) {
-        setHasMoreFrames(m_currentThread, false);
-        fetchFrames(m_currentThread,
-                    m_frames[m_currentThread].count(),
-                    m_frames[m_currentThread].count()-1+fetch);
+    d->m_subsequentFrameFetchOperations += 1;
+    const int fetch = 20 * d->m_subsequentFrameFetchOperations * d->m_subsequentFrameFetchOperations;
+    if (d->m_currentThread != -1 && d->m_hasMoreFrames[d->m_currentThread]) {
+        setHasMoreFrames(d->m_currentThread, false);
+        fetchFrames(d->m_currentThread,
+                    d->m_frames[d->m_currentThread].count(),
+                    d->m_frames[d->m_currentThread].count()-1+fetch);
     }
 }
 
 }
-
