@@ -81,7 +81,7 @@ public:
 
     using TreeItem::model;
 
-    ~Variable();
+    ~Variable() override;
 
     /* Connects this variable to debugger, fetching the current value and
        otherwise preparing this variable to be displayed everywhere.  
@@ -108,10 +108,10 @@ protected:
     bool topLevel() const { return topLevel_; }
 
 private: // TreeItem overrides
-
     QVariant data(int column, int role) const override;
 
 private:
+    bool isPotentialProblematicValue() const;
 
     QString expression_;
     bool inScope_;
@@ -124,6 +124,7 @@ private:
 
 class KDEVPLATFORMDEBUGGER_EXPORT TooltipRoot : public TreeItem
 {
+    Q_OBJECT
 public:
     explicit TooltipRoot(TreeModel* model)
     : TreeItem(model)
@@ -139,6 +140,7 @@ public:
 
 class KDEVPLATFORMDEBUGGER_EXPORT Watches : public TreeItem
 {
+    Q_OBJECT
     friend class GDBDebugger::GdbTest;
 public:
     Watches(TreeModel* model, TreeItem* parent);
@@ -164,6 +166,7 @@ private:
 
 class KDEVPLATFORMDEBUGGER_EXPORT Locals : public TreeItem
 {
+    Q_OBJECT
 public:
     Locals(TreeModel* model, TreeItem* parent, const QString &name);
     QList<Variable*> updateLocals(QStringList locals);
@@ -181,11 +184,12 @@ private:
 
 class KDEVPLATFORMDEBUGGER_EXPORT VariablesRoot : public TreeItem
 {
+    Q_OBJECT
 public:
     explicit VariablesRoot(TreeModel* model);
 
     Watches *watches() const { return watches_; }
-    Locals *locals(const QString &name = QLatin1String("Locals"));
+    Locals *locals(const QString &name = QStringLiteral("Locals"));
     QHash<QString, Locals*> allLocals() const;
 
     void fetchMoreChildren() override {}
@@ -201,7 +205,7 @@ class VariableProvider : public KTextEditor::TextHintProvider
 {
 public:
     explicit VariableProvider(VariableCollection* collection);
-    virtual QString textHint(KTextEditor::View* view, const KTextEditor::Cursor& position) override;
+    QString textHint(KTextEditor::View* view, const KTextEditor::Cursor& position) override;
 
 private:
     VariableCollection* m_collection;
@@ -219,7 +223,7 @@ public:
     };
 
     explicit VariableCollection(IDebugController* parent);
-    virtual ~VariableCollection();
+    ~VariableCollection() override;
 
     VariablesRoot* root() const { return universe_; }
     Watches* watches() const { return universe_->watches(); }
