@@ -25,12 +25,12 @@
 #include "variablecollection.h"
 
 class KHistoryComboBox;
-
+class QSortFilterProxyModel;
 namespace KDevelop
 {
 
 class IDebugController;
-
+class TreeModel;
 class VariableTree;
 class AbstractVariableItem;
 
@@ -50,13 +50,14 @@ public Q_SLOTS:
     void slotAddWatch(const QString &ident);
 
 protected:
-    virtual void showEvent(QShowEvent* e) override;
-    virtual void hideEvent(QHideEvent* e) override;
+    void showEvent(QShowEvent* e) override;
+    void hideEvent(QHideEvent* e) override;
 
 private:
     VariableTree *varTree_;
     KHistoryComboBox *watchVarEditor_;
     VariablesRoot *variablesRoot_;
+    QSortFilterProxyModel *m_proxy;
 };
 
 /***************************************************************************/
@@ -67,14 +68,14 @@ class VariableTree : public KDevelop::AsyncTreeView
 {
     Q_OBJECT
 public:
-    VariableTree(IDebugController *controller, VariableWidget *parent);
-    virtual ~VariableTree();
+    VariableTree(IDebugController *controller, VariableWidget *parent, QSortFilterProxyModel *proxy);
+    ~VariableTree() override;
 
     VariableCollection* collection() const;
 
 private:
     void setupActions();
-    virtual void contextMenuEvent(QContextMenuEvent* event) override;
+    void contextMenuEvent(QContextMenuEvent* event) override;
     Variable *selectedVariable() const;
 
 private slots:
@@ -109,6 +110,8 @@ private:
     QAction *m_copyVariableValue;
     QAction *m_stopOnChange;
     QSignalMapper *m_signalMapper;
+    QSortFilterProxyModel *m_proxy;
+    TreeModel *m_model;
 };
 
 }
