@@ -129,6 +129,16 @@ public:
     /*! @p status must implement KDevelop::IStatus */
     virtual void registerStatus(QObject* status) = 0;
 
+    /**
+     * Shows an assistant popup at bottom within the current central widget
+     * @p assistant the assistant that will be shown in a popup */
+    virtual void popUpAssistant(const QExplicitlySharedDataPointer<IAssistant>& assistant) = 0;
+
+    /**
+     * Hides the assistant if it is currently being shown
+     */
+    virtual void hideAssistant() = 0;
+    
     /**
      * This is meant to be used by IDocument subclasses to initialize the
      * Sublime::Document.
