@@ -18,11 +18,12 @@
 #define KDEVPLATFORM_CODEGENERATOR_H
 
 #include "language/editor/documentrange.h"
-#include "../duchain/indexedstring.h"
+#include <serialization/indexedstring.h>
 #include "../duchain/topducontext.h"
 #include "../duchain/duchain.h"
 
 #include "language/interfaces/iastcontainer.h"
+#include "util/debug.h"
 
 namespace KDevelop
 {
@@ -182,7 +183,7 @@ protected:
     {
         if(!m_AstContainers.contains(file))
         {
-            kDebug() << "Ast requested for: " << file.str();
+            qCDebug(LANGUAGE) << "Ast requested for: " << file.str();
 
             TopDUContext * context = DUChain::self()->waitForUpdate(file, KDevelop::TopDUContext::AST).data();
 
