@@ -35,9 +35,10 @@
 #include "../duchain.h"
 #include "../ducontext.h"
 #include "../identifier.h"
-#include "../indexedstring.h"
 #include "../parsingenvironment.h"
 
+#include <serialization/indexedstring.h>
+
 namespace KDevelop
 {
 /**
@@ -127,7 +128,7 @@ protected:
       context = contextFromNode(node);
 
     Q_ASSERT(context);
-    
+
     openContext( context );
 
     startVisiting(node);
@@ -298,7 +299,7 @@ protected:
 
       if ( contextFromNode( node ) == parent )
       {
-          kDebug() << "Error in AbstractContextBuilder::buildSubContexts(...): du-context was not replaced with new one";
+          qDebug() << "Error in AbstractContextBuilder::buildSubContexts(...): du-context was not replaced with new one";
           DUChainWriteLocker lock( DUChain::lock() );
           deleteContextOnNode( node );
       }
@@ -567,7 +568,7 @@ protected:
    * \param identifier The identifier which corresponds to the context.
    * \returns the opened context.
    */
-  
+
   virtual DUContext* openContextInternal( const RangeInRevision& range, DUContext::ContextType type, const QualifiedIdentifier& identifier )
   {
     Q_ASSERT( m_compilingContexts );
@@ -580,6 +581,7 @@ protected:
         const QVector<DUContext*>& childContexts = currentContext()->childContexts();
 
         int currentIndex = nextContextIndex();
+        const auto indexedIdentifier = IndexedQualifiedIdentifier(identifier);
 
         for ( ; currentIndex < childContexts.count(); ++currentIndex )
         {
@@ -592,8 +594,8 @@ protected:
           // We cannot update a contexts local scope identifier, that will break many other parts, like e.g.
           // the CodeModel of child contexts or declarations.
           // For unnamed child-ranges, we still do range-comparison, because we cannot distinguish them in other ways
-          if ((!identifier.isEmpty() && child->localScopeIdentifier() == identifier)
-              || (identifier.isEmpty() && child->localScopeIdentifier().isEmpty() && !childRange.isEmpty() && childRange == range))
+          if ((!identifier.isEmpty() && child->indexedLocalScopeIdentifier() == indexedIdentifier)
+              || (identifier.isEmpty() && child->indexedLocalScopeIdentifier().isEmpty() && !childRange.isEmpty() && childRange == range))
           {
             // Match
             ret = child;
