@@ -22,27 +22,25 @@
 
 #include <QtCore/QList>
 #include <QtCore/QMap>
-//#include <QtCore/qcontainerfwd.h>
 
-#include "identifier.h"
-#include "indexedstring.h"
 #include "types/abstracttype.h"
 #include "duchainbase.h"
-#include "topducontext.h"
+#include "instantiationinformation.h"
+#include "identifier.h"
+#include "indexeddeclaration.h"
 
 class QByteArray;
 
 namespace KDevelop
 {
-
 class AbstractType;
 class DUContext;
-class Use;
-class ForwardDeclaration;
+class IndexedString;
 class DeclarationData;
 class DeclarationId;
 class Declaration;
 class IndexedTopDUContext;
+class TopDUContext;
 
 
 /**
@@ -56,20 +54,21 @@ class KDEVPLATFORMLANGUAGE_EXPORT Declaration : public DUChainBase
 {
 public:
   /// Access types
-  enum AccessPolicy {
+  enum AccessPolicy : quint8 {
     Public    /**< a public declaration */,
     Protected /**< a protected declaration */,
     Private   /**< a private declaration */,
     DefaultAccess /**<a declaration with default access; in java, only package-level access. */
   };
   /// Enumeration of the types of declarations
-  enum Kind {
+  enum Kind : quint8 {
     Type     /**< A type is declared, like a class-declaration or function-declaration, or a typedef("class MyClass {};") */,
     Instance /**< An instance of a type is declared("MyClass m;") */,
     NamespaceAlias/**< This is a namespace-alias. You can safely cast this object to NamespaceAliasDeclaration. */,
     Alias, /**<This is an alias-declaration. You can safely cast this object to AliasDeclaration. */
     Namespace, /**< Declaration of a namespace. */
-    Import /**< Declaration marks the Import of a file. */
+    Import, /**< Declaration marks the Import of a file. */
+    Macro /**< Declaration of a macro such as "#define FOO 1". */
   };
 
   /**
@@ -88,9 +87,9 @@ public:
   /// Destructor
   virtual ~Declaration();
   /// Uses the given data
-  Declaration( DeclarationData & dd );
+  explicit Declaration( DeclarationData & dd );
 
-  virtual TopDUContext* topContext() const;
+  virtual TopDUContext* topContext() const override;
 
   /**
    * Determine whether this declaration is a forward declaration.
@@ -98,14 +97,6 @@ public:
    * \returns true if this is a forward declaration, otherwise returns false.
    */
   virtual bool isForwardDeclaration() const;
-  /**
-   * \returns this declaration as a forward declaration if it is one, otherwise null.
-   */
-  ForwardDeclaration* toForwardDeclaration();
-  /**
-   * \returns this declaration as a forward declaration, if it is one, otherwise null.
-   */
-  const ForwardDeclaration* toForwardDeclaration() const;
 
   /**
    * Determine whether this declaration is a function declaration.
@@ -152,15 +143,15 @@ public:
   void setIsTypeAlias(bool typeAlias);
 
   /**
-   * Determine whether the declaration is final, ie, it can only be written to once.
+   * Determine whether the declaration is deprecated.
    */
-  bool isFinal() const;
+  bool isDeprecated() const;
   /**
-   * Set whether the declaration is final.
+   * Set whether the declaration is deprecated.
    *
-   * \param final true if the declaration is final, otherwise false.
+   * \param final true if the declaration is deprecated, otherwise false.
    */
-  void setFinal(bool final);
+  void setDeprecated(bool deprecated);
 
   /**
    * Changes whether this declaration must be direct in all cases or not.
@@ -457,7 +448,7 @@ public:
    *
    * \note This is a non-trivial operation and hence expensive.
    */
-  QMap<IndexedString, QList<SimpleRange> > usesCurrentRevision() const;
+  QMap<IndexedString, QList<KTextEditor::Range> > usesCurrentRevision() const;
 
   /**
     * This hash-value should differentiate between multiple different
@@ -565,7 +556,7 @@ private:
 
   void updateCodeModel();
 
-  void rebuildDynamicData(DUContext* parent, uint ownIndex);
+  void rebuildDynamicData(DUContext* parent, uint ownIndex) override;
 
   friend class DUContext;
   friend class IndexedDeclaration;
@@ -576,11 +567,6 @@ private:
   int m_indexInTopContext;
 };
 
-inline uint qHash(const IndexedDeclaration& decl) {
-  return decl.hash();
-}
 }
 
 #endif // KDEVPLATFORM_DECLARATION_H
-
-// kate: space-indent on; indent-width 2; tab-width 4; replace-tabs on; auto-insert-doxygen on
