@@ -297,7 +297,7 @@ class DUChainPrivate
       DUChainPrivate* m_data;
   };
 public:
-  DUChainPrivate() : m_chainsMutex(QMutex::Recursive), m_cleanupMutex(QMutex::Recursive), instance(0), m_cleanupDisabled(false), m_destroyed(false), m_environmentListInfo("Environment Lists"), m_environmentInfo("Environment Information")
+  DUChainPrivate() : m_chainsMutex(QMutex::Recursive), m_cleanupMutex(QMutex::Recursive), instance(0), m_cleanupDisabled(false), m_destroyed(false), m_environmentListInfo(QStringLiteral("Environment Lists")), m_environmentInfo(QStringLiteral("Environment Information"))
   {
 #if defined(TEST_NO_CLEANUP)
     m_cleanupDisabled = true;
@@ -344,7 +344,7 @@ public:
       if(opened)
       {
         Q_ASSERT( (f.size() % sizeof(uint)) == 0);
-        m_availableTopContextIndices.resize(f.size()/sizeof(uint));
+        m_availableTopContextIndices.resize(f.size()/(int)sizeof(uint));
         f.read((char*)m_availableTopContextIndices.data(), f.size());
       }
     }
@@ -516,7 +516,7 @@ public:
 
       //Process the indices in a separate step after copying them from the array, so we don't need m_environmentListInfo.mutex locked,
       //and can call loadInformation(..) safely, which else might lead to a deadlock.
-      for (uint topContextIndex : topContextIndices) {
+      foreach (uint topContextIndex, topContextIndices) {
         QExplicitlySharedDataPointer< ParsingEnvironmentFile > p = ParsingEnvironmentFilePointer(loadInformation(topContextIndex));
         if(p) {
          ret << p;
@@ -529,7 +529,7 @@ public:
     QMutexLocker l(&m_chainsMutex);
 
     //Add those information that have not been added to the stored lists yet
-    foreach(ParsingEnvironmentFilePointer file, m_fileEnvironmentInformations.values(url))
+    foreach(const ParsingEnvironmentFilePointer& file, m_fileEnvironmentInformations.values(url))
       if(!ret.contains(file))
         ret << file;
 
@@ -714,7 +714,7 @@ public:
       writeLock.unlock();
 
       //Here we wait for all parsing-threads to stop their processing
-      foreach(const auto& language, lockedParseMutexes) {
+      foreach(const auto language, lockedParseMutexes) {
         language->parseLock()->lockForWrite();
         locked << language->parseLock();
       }
@@ -1494,7 +1494,7 @@ void DUChain::documentLoadedPrepare(KDevelop::IDocument* doc)
         if(allImportsLoaded) {
           l.unlock();
           lock.unlock();
-          foreach(const auto& language, languages) {
+          foreach(const auto language, languages) {
             if(language->codeHighlighting()) {
               language->codeHighlighting()->highlightDUChain(standardContext);
             }
@@ -1605,7 +1605,7 @@ uint DUChain::newTopContextIndex() {
       return ret;
     }
   }
-  static QAtomicInt& currentId( globalItemRepositoryRegistry().getCustomCounter("Top-Context Counter", 1) );
+  static QAtomicInt& currentId( globalItemRepositoryRegistry().getCustomCounter(QStringLiteral("Top-Context Counter"), 1) );
   return currentId.fetchAndAddRelaxed(1);
 }
 
