@@ -41,6 +41,8 @@
 #include "classdeclaration.h"
 #include "parsingenvironment.h"
 
+#include <QStandardPaths>
+
 using namespace KDevelop;
 using namespace KTextEditor;
 
@@ -148,7 +150,10 @@ CodeCompletionModel::CompletionProperties DUChainUtils::completionProperties(con
  * and for some reason will be loaded every time it's used(this function returns a QIcon marked "load on demand"
  * each time this is called). And the loading is very slow. Seems like a bug somewhere, it cannot be ment to be that slow.
  */
-#define RETURN_CACHED_ICON(name) {static QIcon icon(QIcon::fromTheme(name).pixmap(QSize(16, 16))); return icon;}
+#define RETURN_CACHED_ICON(name) {static QIcon icon(QIcon( \
+      QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kdevelop/pics/" name ".png"))\
+    ).pixmap(QSize(16, 16)));\
+    return icon;}
 
 QIcon DUChainUtils::iconForProperties(KTextEditor::CodeCompletionModel::CompletionProperties p)
 {
@@ -243,7 +248,7 @@ TopDUContext* DUChainUtils::contentContextFromProxyContext(TopDUContext* top)
   if(top->parsingEnvironmentFile() && top->parsingEnvironmentFile()->isProxyContext()) {
     if(!top->importedParentContexts().isEmpty())
     {
-      DUContext* ctx = top->importedParentContexts()[0].context(0);
+      DUContext* ctx = top->importedParentContexts().at(0).context(0);
       if(!ctx)
         return 0;
       TopDUContext* ret = ctx->topContext();
@@ -267,7 +272,7 @@ TopDUContext* DUChainUtils::standardContextForUrl(const QUrl& url, bool preferPr
 
   auto languages = ICore::self()->languageController()->languagesForUrl(url);
 
-  foreach(const auto& language, languages)
+  foreach(const auto language, languages)
   {
     if(!chosen)
     {
@@ -477,8 +482,7 @@ QList<IndexedDeclaration> DUChainUtils::collectAllVersions(Declaration* decl) {
   return ret;
 }
 
-///For a class, returns all classes that inherit it
-QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& maxAllowedSteps, bool collectVersions)
+static QList<Declaration*> getInheritersInternal(const Declaration* decl, uint& maxAllowedSteps, bool collectVersions)
 {
   QList<Declaration*> ret;
 
@@ -489,7 +493,7 @@ QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& m
     return ret;
 
   if(decl->internalContext() && decl->internalContext()->type() == DUContext::Class)
-    for (const IndexedDUContext& importer : decl->internalContext()->indexedImporters()) {
+    foreach (const IndexedDUContext importer, decl->internalContext()->indexedImporters()) {
 
       DUContext* imp = importer.data();
 
@@ -516,7 +520,7 @@ QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& m
       ++maxAllowedSteps;
 
       if(allDeclarations[a].data() && allDeclarations[a].data() != decl) {
-        ret += getInheriters(allDeclarations[a].data(), maxAllowedSteps, false);
+        ret += getInheritersInternal(allDeclarations[a].data(), maxAllowedSteps, false);
       }
 
       if(maxAllowedSteps == 0)
@@ -527,6 +531,17 @@ QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& m
   return ret;
 }
 
+QList<Declaration*> DUChainUtils::getInheriters(const Declaration* decl, uint& maxAllowedSteps, bool collectVersions)
+{
+  auto inheriters = getInheritersInternal(decl, maxAllowedSteps, collectVersions);
+
+  // remove duplicates
+  std::sort(inheriters.begin(), inheriters.end());
+  inheriters.erase(std::unique(inheriters.begin(), inheriters.end()), inheriters.end());
+
+  return inheriters;
+}
+
 QList<Declaration*> DUChainUtils::getOverriders(const Declaration* currentClass, const Declaration* overriddenDeclaration, uint& maxAllowedSteps) {
   QList<Declaration*> ret;
 
