@@ -20,6 +20,7 @@
 #include "ducontext.h"
 
 #include <limits>
+#include <algorithm>
 
 #include <QMutableLinkedListIterator>
 #include <QSet>
@@ -85,12 +86,12 @@ DUChainVisitor::~DUChainVisitor()
  * of Identifier is not safe to be called after the duchain has been destroyed
  */
 const Identifier& globalImportIdentifier() {
-  static const Identifier globalImportIdentifierObject(*new Identifier("{...import...}"));
+  static const Identifier globalImportIdentifierObject(*new Identifier(QStringLiteral("{...import...}")));
   return globalImportIdentifierObject;
 }
 
 const Identifier& globalAliasIdentifier() {
-  static const Identifier globalAliasIdentifierObject(*new Identifier("{...alias...}"));
+  static const Identifier globalAliasIdentifierObject(*new Identifier(QStringLiteral("{...alias...}")));
   return globalAliasIdentifierObject;
 }
 
@@ -612,7 +613,8 @@ void DUContext::findLocalDeclarationsInternal( const IndexedIdentifier& identifi
 {
   Checker checker(flags, dataType, position, type());
 
-  if (d_func()->m_inSymbolTable && !d_func()->m_scopeIdentifier.isEmpty() && !identifier.isEmpty()) {
+  DUCHAIN_D(DUContext);
+  if (d->m_inSymbolTable && !d->m_scopeIdentifier.isEmpty() && !identifier.isEmpty()) {
     //This context is in the symbol table, use the symbol-table to speed up the search
     QualifiedIdentifier id(scopeIdentifier(true) + identifier);
 
@@ -667,7 +669,7 @@ bool DUContext::findDeclarationsInternal( const SearchItem::PtrList & baseIdenti
   }
 
   DUCHAIN_D(DUContext);
-  if (d_func()->m_contextType != Namespace) {
+  if (d->m_contextType != Namespace) {
     // If we're in a namespace, delay all the searching into the top-context, because only that has the overview to pick the correct declarations.
     for (int a = 0; a < baseIdentifiers.size(); ++a) {
       if (!baseIdentifiers[a]->isExplicitlyGlobal && baseIdentifiers[a]->next.isEmpty()) {
@@ -755,7 +757,7 @@ QList< QualifiedIdentifier > DUContext::fullyApplyAliases(const QualifiedIdentif
   }
 
   QList<QualifiedIdentifier> ret;
-  for (const SearchItem::Ptr& item : identifiers)
+  foreach (const SearchItem::Ptr& item, identifiers)
     ret += item->toList();
 
   return ret;
@@ -874,7 +876,7 @@ QVector<DUContext*> DUContext::importers() const
   if(owner()) {
     //Add indirect importers to the list
     KDevVarLengthArray<IndexedDUContext> indirect = Importers::self().importers(owner()->id());
-    for (const IndexedDUContext& ctx : indirect) {
+    foreach (const IndexedDUContext ctx, indirect) {
       ret << ctx.context();
     }
   }
@@ -1203,7 +1205,7 @@ void DUContext::applyAliases(const SearchItem::PtrList& baseIdentifiers, SearchI
       if( !imports.isEmpty() )
       {
         //We have namespace-imports.
-        for ( Declaration* importDecl : imports )
+        foreach ( Declaration* importDecl, imports )
         {
           //Search for the identifier with the import-identifier prepended
           if(dynamic_cast<NamespaceAliasDeclaration*>(importDecl))
@@ -1224,7 +1226,7 @@ void DUContext::applyAliases(const SearchItem::PtrList& baseIdentifiers, SearchI
         if(!aliases.isEmpty()) {
           //The first part of the identifier has been found as a namespace-alias.
           //In c++, we only need the first alias. However, just to be correct, follow them all for now.
-          for ( Declaration* aliasDecl : aliases )
+          foreach ( Declaration* aliasDecl, aliases )
           {
             if(!dynamic_cast<NamespaceAliasDeclaration*>(aliasDecl))
               continue;
@@ -1669,4 +1671,37 @@ void DUContext::visit(DUChainVisitor& visitor)
   }
 }
 
+static bool sortByRange(const DUChainBase* lhs, const DUChainBase* rhs)
+{
+  return lhs->range() < rhs->range();
+}
+
+void DUContext::resortLocalDeclarations()
+{
+  ENSURE_CAN_WRITE
+
+  std::sort(m_dynamicData->m_localDeclarations.begin(), m_dynamicData->m_localDeclarations.end(), sortByRange);
+
+  auto top = topContext();
+  auto& declarations = d_func_dynamic()->m_localDeclarationsList();
+  std::sort(declarations.begin(), declarations.end(),
+            [top] (const LocalIndexedDeclaration& lhs, const LocalIndexedDeclaration& rhs) {
+              return lhs.data(top)->range() < rhs.data(top)->range();
+            });
+}
+
+void DUContext::resortChildContexts()
+{
+  ENSURE_CAN_WRITE
+
+  std::sort(m_dynamicData->m_childContexts.begin(), m_dynamicData->m_childContexts.end(), sortByRange);
+
+  auto top = topContext();
+  auto& contexts = d_func_dynamic()->m_childContextsList();
+  std::sort(contexts.begin(), contexts.end(),
+            [top] (const LocalIndexedDUContext& lhs, const LocalIndexedDUContext& rhs) {
+              return lhs.data(top)->range() < rhs.data(top)->range();
+            });
+}
+
 }
