@@ -93,7 +93,7 @@ public:
    * Destructor. Will delete all child contexts which are defined within
    * the same file as this context.
    */
-  virtual ~DUContext();
+  ~DUContext() override;
 
   enum ContextType : quint8 {
     Global    /**< A context that declares functions, namespaces or classes */,
@@ -151,7 +151,7 @@ public:
   /**
    * Find the top context.
    */
-  virtual TopDUContext* topContext() const override;
+  TopDUContext* topContext() const override;
 
   /**
    * Visits all duchain objects in the whole duchain.
@@ -397,6 +397,14 @@ public:
    */
   void deleteChildContextsRecursively();
 
+  /**
+   * Resort the child contexts by their range.
+   *
+   * You must call this when you manually change the range of child contexts in a way
+   * that could break the internal range sorting.
+   */
+  void resortChildContexts();
+
   /**
    * Returns true if this declaration is accessible through the du-chain,
    * and thus cannot be edited without a du-chain write lock
@@ -509,6 +517,14 @@ public:
    */
   virtual QVector<Declaration*> localDeclarations(const TopDUContext* source = 0) const;
 
+  /**
+   * Resort the local declarations by their range.
+   *
+   * You must call this when you manually change the range of declarations in a way
+   * that could break the internal range sorting.
+   */
+  void resortLocalDeclarations();
+
   /**
    * Searches for the most specific context for the given cursor @a position in the given @a url.
    *
