@@ -160,20 +160,25 @@ QString pathForTopContext(const uint topContextIndex)
   return basePath() + QString::number(topContextIndex);
 }
 
+enum LoadType {
+  PartialLoad, ///< Only load the direct member data
+  FullLoad     ///< Load everything, including appended lists
+};
 template<typename F>
-void loadPartialData(const uint topContextIndex, F callback)
+void loadTopDUContextData(const uint topContextIndex, LoadType loadType, F callback)
 {
   QFile file(pathForTopContext(topContextIndex));
-  if (file.open(QIODevice::ReadOnly)) {
-     uint readValue;
-     file.read((char*)&readValue, sizeof(uint));
-     // now readValue is filled with the top-context data size
-
-     // We only read the most needed stuff, not the whole top-context data
-     QByteArray data = file.read(sizeof(TopDUContextData));
-     const TopDUContextData* topData = reinterpret_cast<const TopDUContextData*>(data.constData());
-     callback(topData);
+  if (!file.open(QIODevice::ReadOnly)) {
+    return;
   }
+
+  uint readValue;
+  file.read((char*)&readValue, sizeof(uint));
+  // now readValue is filled with the top-context data size
+  Q_ASSERT(readValue >= sizeof(TopDUContextData));
+  const QByteArray data = file.read(loadType == FullLoad ? readValue : sizeof(TopDUContextData));
+  const TopDUContextData* topData = reinterpret_cast<const TopDUContextData*>(data.constData());
+  callback(topData);
 }
 
 template<typename T>
@@ -358,15 +363,15 @@ Item TopDUContextDynamicData::DUChainItemStorage<Item>::getItemForIndex(uint ind
     if(index == 0 || index > uint(temporaryItems.size()))
       return {};
     else
-      return temporaryItems[index-1];
+      return temporaryItems.at(index-1);
   }
 
   if (index == 0 || index > static_cast<uint>(items.size())) {
     qCWarning(LANGUAGE) << "item index out of bounds:" << index << "count:" << items.size();
     return {};
   }
-  const uint realIndex = index - 1;
-  Item& item = items[realIndex];
+  const uint realIndex = index - 1;;
+  const auto& item = items.at(realIndex);
   if (item) {
     //Shortcut, because this is the most common case
     return item;
@@ -381,6 +386,7 @@ Item TopDUContextDynamicData::DUChainItemStorage<Item>::getItemForIndex(uint ind
       reinterpret_cast<const DUChainBaseData*>(data->pointerInData(offsets[realIndex].dataOffset))
     );
 
+    auto& item = items[realIndex];
     item = dynamic_cast<typename PtrType<Item>::value>(DUChainItemSystem::self().create(itemData));
     if (!item) {
       //When this happens, the item has not been registered correctly.
@@ -498,7 +504,7 @@ bool TopDUContextDynamicData::fileExists(uint topContextIndex)
 
 QList<IndexedDUContext> TopDUContextDynamicData::loadImporters(uint topContextIndex) {
   QList<IndexedDUContext> ret;
-  loadPartialData(topContextIndex, [&ret] (const TopDUContextData* topData) {
+  loadTopDUContextData(topContextIndex, FullLoad, [&ret] (const TopDUContextData* topData) {
     ret.reserve(topData->m_importersSize());
     FOREACH_FUNCTION(const IndexedDUContext& importer, topData->m_importers)
       ret << importer;
@@ -508,7 +514,7 @@ QList<IndexedDUContext> TopDUContextDynamicData::loadImporters(uint topContextIn
 
 QList<IndexedDUContext> TopDUContextDynamicData::loadImports(uint topContextIndex) {
   QList<IndexedDUContext> ret;
-  loadPartialData(topContextIndex, [&ret] (const TopDUContextData* topData) {
+  loadTopDUContextData(topContextIndex, FullLoad, [&ret] (const TopDUContextData* topData) {
     ret.reserve(topData->m_importedContextsSize());
     FOREACH_FUNCTION(const DUContext::Import& import, topData->m_importedContexts)
       ret << import.indexedContext();
@@ -518,7 +524,7 @@ QList<IndexedDUContext> TopDUContextDynamicData::loadImports(uint topContextInde
 
 IndexedString TopDUContextDynamicData::loadUrl(uint topContextIndex) {
   IndexedString url;
-  loadPartialData(topContextIndex, [&url] (const TopDUContextData* topData) {
+  loadTopDUContextData(topContextIndex, PartialLoad, [&url] (const TopDUContextData* topData) {
     Q_ASSERT(topData->m_url.isEmpty() || topData->m_url.index() >> 16);
     url = topData->m_url;
   });
@@ -654,9 +660,9 @@ void TopDUContextDynamicData::store() {
     return;
   }
 
-    ///@todo Save the meta-data into a repository, and only the actual content data into a file.
-    ///      This will make saving+loading more efficient, and will reduce the disk-usage.
-    ///      Then we also won't need to load the data if only the meta-data changed.
+  ///@todo Save the meta-data into a repository, and only the actual content data into a file.
+  ///      This will make saving+loading more efficient, and will reduce the disk-usage.
+  ///      Then we also won't need to load the data if only the meta-data changed.
   if(!m_dataLoaded)
     loadData();
 
@@ -671,7 +677,7 @@ void TopDUContextDynamicData::store() {
   Q_ASSERT(m_topContext->d_func()->m_ownIndex == m_topContext->ownIndex());
 
   uint topContextDataSize = DUChainItemSystem::self().dynamicSize(*m_topContext->d_func());
-  m_topContextData.append( qMakePair(QByteArray(DUChainItemSystem::self().dynamicSize(*m_topContext->d_func()), topContextDataSize), (uint)0) );
+  m_topContextData.append( qMakePair(QByteArray(DUChainItemSystem::self().dynamicSize(*m_topContext->d_func()), topContextDataSize), 0u) );
   uint actualTopContextDataSize = 0;
 
   if (contentDataChanged) {
@@ -687,8 +693,7 @@ void TopDUContextDynamicData::store() {
     foreach(const ArrayWithPosition &array, oldData)
         newDataSize += array.second;
 
-    if(newDataSize < 10000)
-      newDataSize = 10000;
+    newDataSize = std::max(newDataSize, 10000u);
 
     //We always put 1 byte to the front, so we don't have zero data-offsets, since those are used for "invalid".
     uint currentDataOffset = 1;
@@ -743,12 +748,13 @@ void TopDUContextDynamicData::store() {
 TopDUContextDynamicData::ItemDataInfo TopDUContextDynamicData::writeDataInfo(const ItemDataInfo& info, const DUChainBaseData* data, uint& totalDataOffset) {
   ItemDataInfo ret(info);
   Q_ASSERT(info.dataOffset);
-  int size = DUChainItemSystem::self().dynamicSize(*data);
+  const auto size = DUChainItemSystem::self().dynamicSize(*data);
   Q_ASSERT(size);
 
-  if(m_data.back().first.size() - int(m_data.back().second) < size)
+  if(m_data.back().first.size() - m_data.back().second < size) {
       //Create a new m_data item
-      m_data.append( qMakePair(QByteArray(size > 10000 ? size : 10000, 0), 0u) );
+      m_data.append( qMakePair(QByteArray(std::max(size, 10000u), 0), 0u) );
+  }
 
   ret.dataOffset = totalDataOffset;
 
@@ -756,11 +762,10 @@ TopDUContextDynamicData::ItemDataInfo TopDUContextDynamicData::writeDataInfo(con
   m_data.back().second += size;
   totalDataOffset += size;
 
-  DUChainBaseData& target(*reinterpret_cast<DUChainBaseData*>(m_data.back().first.data() + pos));
-  memcpy(&target, data, size);
+  auto target = reinterpret_cast<DUChainBaseData*>(m_data.back().first.data() + pos);
+  memcpy(target, data, size);
 
   verifyDataInfo(ret, m_data);
-
   return ret;
 }
 
