@@ -24,7 +24,7 @@
 #include "typeutils.h"
 #include "../duchainlock.h"
 
-#include "../../languageexport.h"
+#include <language/languageexport.h>
 
 namespace KDevelop {
 
@@ -38,7 +38,7 @@ public:
     : KDevelop::StructureTypeData(rhs)
     , m_contentType(rhs.m_contentType) { }
 
-    ListTypeData(const KDevelop::StructureTypeData& rhs)
+    explicit ListTypeData(const KDevelop::StructureTypeData& rhs)
     : KDevelop::StructureTypeData(rhs)
     , m_contentType() { }
 
@@ -79,7 +79,7 @@ public:
 
     ListType();
     ListType(const ListType& rhs);
-    ListType(StructureTypeData& data);
+    explicit ListType(StructureTypeData& data);
 
     /**
      * @brief Adds @p typeToAdd to the content type of this list.
@@ -99,8 +99,8 @@ public:
     void addContentType(AbstractType::Ptr typeToAdd) {
         auto newContentType = TypeUtils::mergeTypes<LanguageUnsureType>(contentType().abstractType(), typeToAdd);
         DUChainWriteLocker lock;
-        d_func_dynamic()->m_contentType = IndexedType(newContentType);
-    };
+        d_func_dynamic()->m_contentType = newContentType->indexed();
+    }
 
     /**
      * @brief Replaces this list's content type by @p newType.
@@ -120,11 +120,11 @@ public:
     /**
      * @brief Formats this type (base type and content type) in a string.
      */
-    virtual QString toString() const;
+    virtual QString toString() const override;
 
-    virtual AbstractType* clone() const;
-    virtual uint hash() const;
-    virtual bool equals(const AbstractType* rhs) const;
+    virtual AbstractType* clone() const override;
+    virtual uint hash() const override;
+    virtual bool equals(const AbstractType* rhs) const override;
 
     enum { Identity = 58 };
 
@@ -145,7 +145,7 @@ public:
     : ListTypeData(rhs)
     , m_keyType(rhs.m_keyType) { }
 
-    MapTypeData(const ListTypeData& rhs)
+    explicit MapTypeData(const ListTypeData& rhs)
     : ListTypeData(rhs)
     , m_keyType() { }
 
@@ -164,7 +164,7 @@ public:
 
     MapType();
     MapType(const MapType& rhs);
-    MapType(ListTypeData& data);
+    explicit MapType(ListTypeData& data);
 
     /**
     * @brief Add @p typeToAdd to this map's key type.
@@ -175,7 +175,7 @@ public:
     {
         auto newKeyType = TypeUtils::mergeTypes<LanguageUnsureType>(keyType().abstractType(), typeToAdd);
         DUChainWriteLocker lock;
-        d_func_dynamic()->m_keyType = IndexedType(newKeyType);
+        d_func_dynamic()->m_keyType = newKeyType->indexed();
     }
 
     /**
@@ -191,11 +191,11 @@ public:
     /**
      * @brief Formats this type (base type and key+content type) in a string.
      */
-    virtual QString toString() const;
+    virtual QString toString() const override;
 
-    virtual AbstractType* clone() const;
-    virtual uint hash() const;
-    virtual bool equals(const AbstractType* rhs) const;
+    virtual AbstractType* clone() const override;
+    virtual uint hash() const override;
+    virtual bool equals(const AbstractType* rhs) const override;
 
     enum { Identity = 57 };
 
