@@ -58,7 +58,7 @@ AbstractType::Ptr TypeAliasType::type() const
 
 void TypeAliasType::setType(AbstractType::Ptr type)
 {
-  d_func_dynamic()->m_type = IndexedType(type);
+  d_func_dynamic()->m_type = type->indexed();
 }
 
 uint TypeAliasType::hash() const
@@ -75,7 +75,7 @@ QString TypeAliasType::toString() const
   if (type())
     return AbstractType::toString(false) + type()->toString();
 
-  return "typedef <notype>";
+  return QStringLiteral("typedef <notype>");
 }
 
 void TypeAliasType::accept0 (KDevelop::TypeVisitor *v) const
@@ -91,7 +91,7 @@ KDevelop::AbstractType::WhichType TypeAliasType::whichType() const {
 }
 
 void TypeAliasType::exchangeTypes(KDevelop::TypeExchanger* exchanger) {
-  d_func_dynamic()->m_type = IndexedType(exchanger->exchange(d_func()->m_type.abstractType()));
+  d_func_dynamic()->m_type = exchanger->exchange( d_func()->m_type.abstractType() )->indexed();
 }
 
 
