@@ -150,7 +150,7 @@ class KDEVPLATFORMLANGUAGE_EXPORT CodeHighlighting : public QObject, public KDev
   public:
 
     explicit CodeHighlighting(QObject* parent);
-    virtual ~CodeHighlighting();
+    ~CodeHighlighting() override;
 
     /// This function is thread-safe
     /// @warning The duchain must not be locked when this is called (->possible deadlock)
@@ -187,7 +187,6 @@ class KDEVPLATFORMLANGUAGE_EXPORT CodeHighlighting : public QObject, public KDev
 
     QMap<DocumentChangeTracker*, DocumentHighlighting*> m_highlights;
 
-    void clearHighlightingForDocument(KDevelop::IndexedString document);
 
     friend class CodeHighlightingInstance;
 
@@ -203,6 +202,7 @@ class KDEVPLATFORMLANGUAGE_EXPORT CodeHighlighting : public QObject, public KDev
     mutable QMutex m_dataMutex;
 
   private Q_SLOTS:
+    void clearHighlightingForDocument(KDevelop::IndexedString document);
     void applyHighlighting(void* highlighting);
 
     void trackerDestroyed(QObject* object);
