@@ -40,6 +40,8 @@ public:
     void childProcessStdout();
     void childProcessStderr();
 
+    void emitProgress(const IFilterStrategy::Progress& progress);
+
     QString joinCommandLine() const;
     QString getJobName();
 
@@ -55,6 +57,7 @@ public:
     OutputExecuteJob::JobStatus m_status;
     OutputExecuteJob::JobProperties m_properties;
     OutputModel::OutputFilterStrategy m_filteringStrategy;
+    QScopedPointer<IFilterStrategy> m_filteringStrategyPtr;
     QStringList m_arguments;
     QStringList m_privilegedExecutionCommand;
     QUrl m_workingDirectory;
@@ -221,9 +224,18 @@ void OutputExecuteJob::start()
     }
     Q_ASSERT( model() );
 
-    model()->setFilteringStrategy( d->m_filteringStrategy );
+    if (d->m_filteringStrategyPtr) {
+        model()->setFilteringStrategy(d->m_filteringStrategyPtr.take());
+    } else {
+        model()->setFilteringStrategy(d->m_filteringStrategy);
+    }
+
     setDelegate( new OutputDelegate );
 
+    connect(model(), &OutputModel::progress, this, [&](const IFilterStrategy::Progress& progress) {
+        d->emitProgress(progress);
+    });
+
     // Slots hasRawStdout() and hasRawStderr() are responsible
     // for feeding raw data to the line maker; so property-based channel filtering is implemented there.
     if( d->m_properties.testFlag( PostProcessOutput ) ) {
@@ -255,11 +267,21 @@ void OutputExecuteJob::start()
     if( !effectiveWorkingDirectory.isEmpty() ) {
         d->m_process->setWorkingDirectory( effectiveWorkingDirectory.toLocalFile() );
     }
-    d->m_process->setProcessEnvironment( d->effectiveEnvironment() );
-    d->m_process->setProgram( d->effectiveCommandLine() );
 
-    qCDebug(OUTPUTVIEW) << "Starting:" << d->m_process->program().join(" ") << "in" << d->m_process->workingDirectory();
-    d->m_process->start();
+    d->m_process->setProcessEnvironment( d->effectiveEnvironment() );
+    if (!d->effectiveCommandLine().isEmpty()) {
+        d->m_process->setProgram( d->effectiveCommandLine() );
+
+        qCDebug(OUTPUTVIEW) << "Starting:" << d->m_process->program().join(QStringLiteral(" ")) << "in" << d->m_process->workingDirectory();
+        d->m_process->start();
+    } else {
+        QString errorMessage = i18n("Failed to specify program to start");
+        model()->appendLine( i18n( "*** %1 ***", errorMessage) );
+        setErrorText(errorMessage);
+        setError( FailedShownError );
+        emitResult();
+        return;
+    }
 }
 
 bool OutputExecuteJob::doKill()
@@ -278,7 +300,7 @@ bool OutputExecuteJob::doKill()
     }
     d->m_lineMaker->flushBuffers();
     if( terminated ) {
-        model()->appendLine( i18n( "*** Aborted ***" ) );
+        model()->appendLine( i18n( "*** Killed process ***" ) );
     } else {
         // It survived SIGKILL, leave it alone...
         model()->appendLine( i18n( "*** Warning: could not kill the process ***" ) );
@@ -297,11 +319,11 @@ void OutputExecuteJob::childProcessError( QProcess::ProcessError processError )
     QString errorValue;
     switch( processError ) {
         case QProcess::FailedToStart:
-            errorValue = i18n("%1 has failed to start", commandLine().first());
+            errorValue = i18n("%1 has failed to start", commandLine().at(0));
             break;
 
         case QProcess::Crashed:
-            errorValue = i18n("%1 has crashed", commandLine().first());
+            errorValue = i18n("%1 has crashed", commandLine().at(0));
             break;
 
         case QProcess::ReadError:
@@ -368,6 +390,16 @@ void OutputExecuteJobPrivate::childProcessStderr()
     }
 }
 
+void OutputExecuteJobPrivate::emitProgress(const IFilterStrategy::Progress& progress)
+{
+    if (progress.percent != -1) {
+        m_owner->emitPercent(progress.percent, 100);
+    }
+    if (!progress.status.isEmpty()) {
+        m_owner->infoMessage(m_owner, progress.status);
+    }
+}
+
 void OutputExecuteJob::postProcessStdout( const QStringList& lines )
 {
     model()->appendLines( lines );
@@ -381,6 +413,17 @@ void OutputExecuteJob::postProcessStderr( const QStringList& lines )
 void OutputExecuteJob::setFilteringStrategy( OutputModel::OutputFilterStrategy strategy )
 {
     d->m_filteringStrategy = strategy;
+
+    // clear the other
+    d->m_filteringStrategyPtr.reset(nullptr);
+}
+
+void OutputExecuteJob::setFilteringStrategy(IFilterStrategy* filterStrategy)
+{
+    d->m_filteringStrategyPtr.reset(filterStrategy);
+
+    // clear the other
+    d->m_filteringStrategy = OutputModel::NoFilter;
 }
 
 OutputExecuteJob::JobProperties OutputExecuteJob::properties() const
@@ -432,17 +475,20 @@ void OutputExecuteJobPrivate::mergeEnvironment( QProcessEnvironment& dest, const
 
 QProcessEnvironment OutputExecuteJobPrivate::effectiveEnvironment() const
 {
-    QProcessEnvironment environment = QProcessEnvironment::systemEnvironment();
     const EnvironmentGroupList environmentGroup( KSharedConfig::openConfig() );
     QString environmentProfile = m_owner->environmentProfile();
     if( environmentProfile.isEmpty() ) {
         environmentProfile = environmentGroup.defaultGroup();
     }
-    OutputExecuteJobPrivate::mergeEnvironment( environment, environmentGroup.variables( environmentProfile ) );
+    QProcessEnvironment environment = QProcessEnvironment::systemEnvironment();
+    auto userEnv = environmentGroup.variables(environmentProfile);
+    expandVariables(userEnv, environment);
+
+    OutputExecuteJobPrivate::mergeEnvironment( environment, userEnv );
     OutputExecuteJobPrivate::mergeEnvironment( environment, m_environmentOverrides );
     if( m_properties.testFlag( OutputExecuteJob::PortableMessages ) ) {
-        environment.remove( "LC_ALL" );
-        environment.insert( "LC_MESSAGES", "C" );
+        environment.remove( QStringLiteral( "LC_ALL" ) );
+        environment.insert( QStringLiteral( "LC_MESSAGES" ), QStringLiteral( "C" ) );
     }
     return environment;
 }
@@ -458,7 +504,7 @@ QStringList OutputExecuteJobPrivate::effectiveCommandLine() const
     // "helper -- our command line".
     QStringList privilegedCommand = m_owner->privilegedExecutionCommand();
     if( !privilegedCommand.isEmpty() ) {
-        return QStringList() << m_owner->privilegedExecutionCommand() << "--" << m_owner->commandLine();
+        return QStringList() << m_owner->privilegedExecutionCommand() << QStringLiteral("--") << m_owner->commandLine();
     } else {
         return m_owner->commandLine();
     }
