@@ -27,9 +27,9 @@
 
 #include <algorithm>
 
-using namespace KDevelop;
+namespace KDevelop
+{
 
-namespace {
 template<typename ErrorFormats>
 FilteredItem match(const ErrorFormats& errorFormats, const QString& line)
 {
@@ -58,7 +58,6 @@ FilteredItem match(const ErrorFormats& errorFormats, const QString& line)
     }
     return item;
 }
-}
 
 /// --- No filter strategy ---
 
@@ -78,12 +77,28 @@ FilteredItem NoFilterStrategy::errorInLine(const QString& line)
 
 /// --- Compiler error filter strategy ---
 
-CompilerFilterStrategy::CompilerFilterStrategy(const QUrl& buildDir)
+/// Impl. of CompilerFilterStrategy.
+struct CompilerFilterStrategyPrivate
+{
+    CompilerFilterStrategyPrivate(const QUrl& buildDir);
+    Path pathForFile( const QString& ) const;
+    bool isMultiLineCase(ErrorFormat curErrFilter) const;
+    void putDirAtEnd(const Path& pathToInsert);
+
+    QVector<Path> m_currentDirs;
+    Path m_buildDir;
+
+    using PositionMap = QHash<Path, int>;
+    PositionMap m_positionInCurrentDirs;
+};
+
+
+CompilerFilterStrategyPrivate::CompilerFilterStrategyPrivate(const QUrl& buildDir)
     : m_buildDir(buildDir)
 {
 }
 
-Path CompilerFilterStrategy::pathForFile(const QString& filename) const
+Path CompilerFilterStrategyPrivate::pathForFile(const QString& filename) const
 {
     QFileInfo fi( filename );
     Path currentPath;
@@ -95,7 +110,7 @@ Path CompilerFilterStrategy::pathForFile(const QString& filename) const
         auto it = m_currentDirs.constEnd() - 1;
         do {
             currentPath = Path(*it, filename);
-        } while( (it-- !=  m_currentDirs.constBegin()) && !QFileInfo(currentPath.toLocalFile()).exists() );
+        } while( (it-- !=  m_currentDirs.constBegin()) && !QFileInfo::exists(currentPath.toLocalFile()) );
 
         return currentPath;
     } else {
@@ -104,17 +119,17 @@ Path CompilerFilterStrategy::pathForFile(const QString& filename) const
     return currentPath;
 }
 
-bool CompilerFilterStrategy::isMultiLineCase(KDevelop::ErrorFormat curErrFilter) const
+bool CompilerFilterStrategyPrivate::isMultiLineCase(KDevelop::ErrorFormat curErrFilter) const
 {
-    if(curErrFilter.compiler == "gfortran" || curErrFilter.compiler == "cmake") {
+    if(curErrFilter.compiler == QLatin1String("gfortran") || curErrFilter.compiler == QLatin1String("cmake")) {
         return true;
     }
     return false;
 }
 
-void CompilerFilterStrategy::putDirAtEnd(const Path& pathToInsert)
+void CompilerFilterStrategyPrivate::putDirAtEnd(const Path& pathToInsert)
 {
-    auto it = m_positionInCurrentDirs.find( pathToInsert );
+    CompilerFilterStrategyPrivate::PositionMap::iterator it = m_positionInCurrentDirs.find( pathToInsert );
     // Encountered new build directory?
     if (it == m_positionInCurrentDirs.end()) {
         m_currentDirs.push_back( pathToInsert );
@@ -127,11 +142,21 @@ void CompilerFilterStrategy::putDirAtEnd(const Path& pathToInsert)
     }
 }
 
+CompilerFilterStrategy::CompilerFilterStrategy(const QUrl& buildDir)
+: d(new CompilerFilterStrategyPrivate( buildDir ))
+{
+}
+
+CompilerFilterStrategy::~CompilerFilterStrategy()
+{
+    delete d;
+}
+
 QVector<QString> CompilerFilterStrategy::getCurrentDirs()
 {
     QVector<QString> ret;
-    ret.reserve(m_currentDirs.size());
-    for (const auto& path : m_currentDirs) {
+    ret.reserve(d->m_currentDirs.size());
+    foreach (const auto& path, d->m_currentDirs) {
         ret << path.pathOrUrl();
     }
     return ret;
@@ -141,51 +166,41 @@ FilteredItem CompilerFilterStrategy::actionInLine(const QString& line)
 {
     // A list of filters for possible compiler, linker, and make actions
     static const ActionFormat ACTION_FILTERS[] = {
-        ActionFormat( ki18nc("compiling a file: %1 file %2 compiler", "compiling %1 (%2)"), 1, 2,
+        ActionFormat( 2,
                       QStringLiteral("(?:^|[^=])\\b(gcc|CC|cc|distcc|c\\+\\+|g\\+\\+|clang(?:\\+\\+)|mpicc|icc|icpc)\\s+.*-c.*[/ '\\\\]+(\\w+\\.(?:cpp|CPP|c|C|cxx|CXX|cs|java|hpf|f|F|f90|F90|f95|F95))")),
         //moc and uic
-        ActionFormat( ki18nc("generating a file: %1 file %2 generator tool", "generating %1 (%2)"), 1, 2,
-                      QStringLiteral("/(moc|uic)\\b.*\\s-o\\s([^\\s;]+)")),
+        ActionFormat( 2, QStringLiteral("/(moc|uic)\\b.*\\s-o\\s([^\\s;]+)")),
         //libtool linking
-        ActionFormat( ki18nc("Linking object files into a library or executable: %1 target, %2 linker", "linking %1 (%2)"),
-                      QStringLiteral("libtool"), QStringLiteral("/bin/sh\\s.*libtool.*--mode=link\\s.*\\s-o\\s([^\\s;]+)"), 1 ),
+        ActionFormat( QStringLiteral("libtool"), QStringLiteral("/bin/sh\\s.*libtool.*--mode=link\\s.*\\s-o\\s([^\\s;]+)"), 1 ),
         //unsermake
-        ActionFormat( ki18nc("compiling a file: %1 file %2 compiler", "compiling %1 (%2)"), 1, 1,
-                      QStringLiteral("^compiling (.*)") ),
-        ActionFormat( ki18nc("generating a file: %1 file %2 generator tool", "generating %1 (%2)"), 1, 2,
-                      QStringLiteral("^generating (.*)") ),
-        ActionFormat( ki18nc("Linking object files into a library or executable: %1 file, %2 linker", "linking %1 (%2)"), 1, 2,
-                      QStringLiteral("(gcc|cc|c\\+\\+|g\\+\\+|clang(?:\\+\\+)|mpicc|icc|icpc)\\S* (?:\\S* )*-o ([^\\s;]+)")),
-        ActionFormat( ki18nc("Linking object files into a library or executable: %1 file, %2 compiler", "linking %1 (%2)"), 1, 2,
-                      QStringLiteral("^linking (.*)") ),
+        ActionFormat( 1, QStringLiteral("^compiling (.*)") ),
+        ActionFormat( 2, QStringLiteral("^generating (.*)") ),
+        ActionFormat( 2, QStringLiteral("(gcc|cc|c\\+\\+|g\\+\\+|clang(?:\\+\\+)|mpicc|icc|icpc)\\S* (?:\\S* )*-o ([^\\s;]+)")),
+        ActionFormat( 2, QStringLiteral("^linking (.*)") ),
         //cmake
-        ActionFormat( ki18nc("finished building a target: %1 target name", "built %1"), -1, 1,
-                      QStringLiteral("\\[.+%\\] Built target (.*)") ),
-        ActionFormat( ki18nc("compiling a file: %1 file %2 compiler", "compiling %1 (%2)"), QStringLiteral("cmake"),
-                      QStringLiteral("\\[.+%\\] Building .* object (.*)CMakeFiles/"), 1 ),
-        ActionFormat( ki18nc("generating a file: %1 file %2 generator tool", "generating %1 (%2)"), -1, 1,
-                      QStringLiteral("\\[.+%\\] Generating (.*)") ),
-        ActionFormat( ki18nc("Linking object files into a library or executable: %1 target", "linking %1"), -1, 1,
-                      QStringLiteral("^Linking (.*)") ),
-        ActionFormat( ki18nc("configuring a project: %1 tool", "configuring (%1)"), QStringLiteral("cmake"),
+        ActionFormat( 1, QStringLiteral("\\[.+%\\] Built target (.*)") ),
+        ActionFormat( QStringLiteral("cmake"),
+                      QStringLiteral("\\[.+%\\] Building .* object (.*)"), 1 ),
+        ActionFormat( 1, QStringLiteral("\\[.+%\\] Generating (.*)") ),
+        ActionFormat( 1, QStringLiteral("^Linking (.*)") ),
+        ActionFormat( QStringLiteral("cmake"),
                       QStringLiteral("(-- Configuring (done|incomplete)|-- Found|-- Adding|-- Enabling)"), -1 ),
-        ActionFormat( ki18nc("installing a file: %1 file", "installing %1"), -1, 1,
-                      QStringLiteral("-- Installing (.*)") ),
+        ActionFormat( 1, QStringLiteral("-- Installing (.*)") ),
         //libtool install
-        ActionFormat( ki18nc("creating a folder: %1 path", "creating %1"), {},
+        ActionFormat( {},
                       QStringLiteral("/(?:bin/sh\\s.*mkinstalldirs).*\\s([^\\s;]+)"), 1 ),
-        ActionFormat( ki18nc("installing a file: %1 file", "installing %1"), {},
+        ActionFormat( {},
                       QStringLiteral("/(?:usr/bin/install|bin/sh\\s.*mkinstalldirs|bin/sh\\s.*libtool.*--mode=install).*\\s([^\\s;]+)"), 1 ),
         //dcop
-        ActionFormat( ki18nc("generating a file: %1 file %2 generator tool", "generating %1 (%2)"), QStringLiteral("dcopidl"),
+        ActionFormat( QStringLiteral("dcopidl"),
                       QStringLiteral("dcopidl .* > ([^\\s;]+)"), 1 ),
-        ActionFormat( ki18nc("compiling a file: %1 file %2 compiler", "compiling %1 (%2)"), QStringLiteral("dcopidl2cpp"),
+        ActionFormat( QStringLiteral("dcopidl2cpp"),
                       QStringLiteral("dcopidl2cpp (?:\\S* )*([^\\s;]+)"), 1 ),
         // match against Entering directory to update current build dir
-        ActionFormat( ki18nc("change directory: %1: path", "entering %1 (%2)"), QStringLiteral("cd"),
+        ActionFormat( QStringLiteral("cd"),
                       QStringLiteral("make\\[\\d+\\]: Entering directory (\\`|\\')(.+)'"), 2),
         // waf and scons use the same basic convention as make
-        ActionFormat( ki18nc("change directory: %1: path", "entering %1 (%2)"), QStringLiteral("cd"),
+        ActionFormat( QStringLiteral("cd"),
                       QStringLiteral("(Waf|scons): Entering directory (\\`|\\')(.+)'"), 3)
     };
 
@@ -194,30 +209,22 @@ FilteredItem CompilerFilterStrategy::actionInLine(const QString& line)
         const auto match = curActFilter.expression.match(line);
         if( match.hasMatch() ) {
             item.type = FilteredItem::ActionItem;
-            KLocalizedString shortened = curActFilter.label;
-            if (curActFilter.fileGroup != -1) {
-                shortened = shortened.subs(match.captured(curActFilter.fileGroup));
-            }
-            if (curActFilter.toolGroup != -1 ) {
-                shortened = shortened.subs(match.captured(curActFilter.toolGroup));
-            } else if (!curActFilter.tool.isEmpty()) {
-                shortened = shortened.subs(curActFilter.tool);
-            }
 
-            item.shortenedText = shortened.toString();
-
-            if( curActFilter.tool == "cd" ) {
+            if( curActFilter.tool == QLatin1String("cd") ) {
                 const Path path(match.captured(curActFilter.fileGroup));
-                m_currentDirs.push_back( path );
-                m_positionInCurrentDirs.insert( path , m_currentDirs.size() - 1 );
+                d->m_currentDirs.push_back( path );
+                d->m_positionInCurrentDirs.insert( path , d->m_currentDirs.size() - 1 );
             }
 
             // Special case for cmake: we parse the "Compiling <objectfile>" expression
             // and use it to find out about the build paths encountered during a build.
             // They are later searched by pathForFile to find source files corresponding to
             // compiler errors.
-            if ( curActFilter.fileGroup != -1 && curActFilter.tool == "cmake" && line.contains("Building")) {
-                putDirAtEnd(Path(m_buildDir, match.captured(curActFilter.fileGroup).mid(1)));
+            // Note: CMake objectfile has the format: "/path/to/four/CMakeFiles/file.o"
+            if ( curActFilter.fileGroup != -1 && curActFilter.tool == QLatin1String("cmake") && line.contains(QStringLiteral("Building"))) {
+                const auto objectFile = match.captured(curActFilter.fileGroup);
+                const auto dir = objectFile.section(QStringLiteral("CMakeFiles/"), 0, 0);
+                d->putDirAtEnd(Path(d->m_buildDir, dir));
             }
             break;
         }
@@ -248,6 +255,10 @@ FilteredItem CompilerFilterStrategy::errorInLine(const QString& line)
 
     // A list of filters for possible compiler, linker, and make errors
     static const ErrorFormat ERROR_FILTERS[] = {
+#ifdef Q_OS_WIN
+        // MSVC
+        ErrorFormat( QStringLiteral("^([a-zA-Z]:\\\\.+)\\(([1-9][0-9]*)\\): ((?:error|warning) .+\\:).*$"), 1, 2, 3 ),
+#endif
         // GCC - another case, eg. for #include "pixmap.xpm" which does not exists
         ErrorFormat( QStringLiteral("^([^:\t]+):([0-9]+):([0-9]+):([^0-9]+)"), 1, 2, 4, 3 ),
         // GCC
@@ -295,12 +306,12 @@ FilteredItem CompilerFilterStrategy::errorInLine(const QString& line)
                                || line.contains( QLatin1String("for each function it appears in.") ) ) )
         {
             if(curErrFilter.fileGroup > 0) {
-                if( curErrFilter.compiler == "cmake" ) { // Unfortunately we cannot know if an error or an action comes first in cmake, and therefore we need to do this
-                    if( m_currentDirs.empty() ) {
-                        putDirAtEnd( m_buildDir.parent() );
+                if( curErrFilter.compiler == QLatin1String("cmake") ) { // Unfortunately we cannot know if an error or an action comes first in cmake, and therefore we need to do this
+                    if( d->m_currentDirs.empty() ) {
+                        d->putDirAtEnd( d->m_buildDir.parent() );
                     }
                 }
-                item.url = pathForFile( match.captured( curErrFilter.fileGroup ) ).toUrl();
+                item.url = d->pathForFile( match.captured( curErrFilter.fileGroup ) ).toUrl();
             }
             item.lineNo = match.captured( curErrFilter.lineGroup ).toInt() - 1;
             if(curErrFilter.columnGroup >= 0) {
@@ -327,7 +338,7 @@ FilteredItem CompilerFilterStrategy::errorInLine(const QString& line)
                 if(item.type == FilteredItem::InvalidItem) {
                     // If there are no error indicators in the line
                     // maybe this is a multiline case
-                    if(isMultiLineCase(curErrFilter)) {
+                    if(d->isMultiLineCase(curErrFilter)) {
                         item.type = FilteredItem::ErrorItem;
                     } else {
                         // Okay so we couldn't find anything to indicate an error, but we have file and lineGroup
@@ -379,14 +390,25 @@ FilteredItem NativeAppErrorFilterStrategy::actionInLine(const QString& line)
 
 FilteredItem NativeAppErrorFilterStrategy::errorInLine(const QString& line)
 {
-    static const ErrorFormat QT_APPLICATION_ERROR_FILTERS[] = {
+    static const ErrorFormat NATIVE_APPLICATION_ERROR_FILTERS[] = {
+        // BEGIN: C++
+
+        // a.out: test.cpp:5: int main(): Assertion `false' failed.
+        ErrorFormat(QStringLiteral("^.+: (.+):([1-9][0-9]*): .*: Assertion `.*' failed\\.$"), 1, 2, -1),
+
+        // END: C++
+
+        // BEGIN: Qt
+
+        // Note: Scan the whole line for catching Qt runtime warnings (-> no ^$)
+        // Reasoning: With QT_MESSAGE_PATTERN you can configure the output to your desire,
+        // which means the output could be arbitrarily prefixed or suffixed with other content
+
         // QObject::connect related errors, also see err_method_notfound() in qobject.cpp
         // QObject::connect: No such slot Foo::bar() in /foo/bar.cpp:313
-        ErrorFormat(QStringLiteral("^QObject::connect: (?:No such|Parentheses expected,) (?:slot|signal) [^ ]* in (.*):([0-9]+)$"), 1, 2, -1),
+        ErrorFormat(QStringLiteral("QObject::connect: (?:No such|Parentheses expected,) (?:slot|signal) [^ ]* in (.*):([0-9]+)"), 1, 2, -1),
         // ASSERT: "errors().isEmpty()" in file /foo/bar.cpp, line 49
-        ErrorFormat(QStringLiteral("^ASSERT: \"(.*)\" in file (.*), line ([0-9]+)$"), 2, 3, -1),
-        // QFATAL : FooTest::testBar() ASSERT: "index.isValid()" in file /foo/bar.cpp, line 32
-        ErrorFormat(QStringLiteral("^QFATAL : (.*) ASSERT: \"(.*)\" in file (.*), line ([0-9]+)$"), 3, 4, -1),
+        ErrorFormat(QStringLiteral("ASSERT: \"(.*)\" in file (.*), line ([0-9]+)"), 2, 3, -1),
         // Catch:
         // FAIL!  : FooTest::testBar() Compared pointers are not the same
         //    Actual   ...
@@ -396,10 +418,14 @@ FilteredItem NativeAppErrorFilterStrategy::errorInLine(const QString& line)
         // Do *not* catch:
         //    ...
         //    Loc: [Unknown file(0)]
-        ErrorFormat(QStringLiteral("^   Loc: \\[(.*)\\(([1-9][0-9]*)\\)\\]$"), 1, 2, -1)
+        ErrorFormat(QStringLiteral("   Loc: \\[(.*)\\(([1-9][0-9]*)\\)\\]"), 1, 2, -1),
+        // file:///path/to/foo.qml:7:1: Bar is not a type
+        ErrorFormat(QStringLiteral("(file:\\/\\/(?:.+)):([1-9][0-9]*):([1-9][0-9]*): (.+) (?:is not a type|is ambiguous\\.|is instantiated recursively)"), 1, 2, -1, 3)
+
+        // END: Qt
     };
 
-    return match(QT_APPLICATION_ERROR_FILTERS, line);
+    return match(NATIVE_APPLICATION_ERROR_FILTERS, line);
 }
 
 /// --- Static Analysis filter strategy ---
@@ -427,3 +453,5 @@ FilteredItem StaticAnalysisFilterStrategy::errorInLine(const QString& line)
 
     return match(STATIC_ANALYSIS_FILTERS, line);
 }
+
+}
