@@ -27,6 +27,7 @@
 
 #include <interfaces/icore.h>
 #include <interfaces/idocumentcontroller.h>
+#include <util/kdevstringhandler.h>
 
 #include <QtCore/QStringList>
 #include <QtCore/QTimer>
@@ -35,10 +36,10 @@
 #include <QApplication>
 #include <QFontDatabase>
 
+#include <functional>
 #include <set>
 
 Q_DECLARE_METATYPE(QVector<KDevelop::FilteredItem>)
-Q_DECLARE_METATYPE(KDevelop::IFilterStrategy*)
 
 namespace KDevelop
 {
@@ -63,7 +64,7 @@ class ParseWorker : public QObject
 public:
     ParseWorker()
         : QObject(0)
-        , m_filter( new NoFilterStrategy )
+        , m_filter(new NoFilterStrategy)
         , m_timer(new QTimer(this))
     {
         m_timer->setInterval(BATCH_AGGREGATE_TIME_DELAY);
@@ -99,6 +100,7 @@ public slots:
 
 signals:
     void parsedBatch(const QVector<KDevelop::FilteredItem>& filteredItems);
+    void progress(const KDevelop::IFilterStrategy::Progress& progress);
     void allDone();
 
 private slots:
@@ -110,6 +112,11 @@ private slots:
         QVector<KDevelop::FilteredItem> filteredItems;
         filteredItems.reserve(qMin(BATCH_SIZE, m_cachedLines.size()));
 
+        // apply pre-filtering functions
+        std::transform(m_cachedLines.constBegin(), m_cachedLines.constEnd(),
+                       m_cachedLines.begin(), &KDevelop::stripAnsiSequences);
+
+        // apply filtering strategy
         foreach(const QString& line, m_cachedLines) {
             FilteredItem item = m_filter->errorInLine(line);
             if( item.type == FilteredItem::InvalidItem ) {
@@ -118,6 +125,12 @@ private slots:
 
             filteredItems << item;
 
+            auto progress = m_filter->progressInLine(line);
+            if (progress.percent >= 0 && m_progress.percent != progress.percent) {
+                m_progress = progress;
+                emit this->progress(m_progress);
+            }
+
             if( filteredItems.size() == BATCH_SIZE ) {
                 emit parsedBatch(filteredItems);
                 filteredItems.clear();
@@ -137,6 +150,7 @@ private:
     QStringList m_cachedLines;
 
     QTimer* m_timer;
+    IFilterStrategy::Progress m_progress;
 };
 
 class ParsingThread
@@ -144,7 +158,7 @@ class ParsingThread
 public:
     ParsingThread()
     {
-        m_thread.setObjectName("OutputFilterThread");
+        m_thread.setObjectName(QStringLiteral("OutputFilterThread"));
     }
     virtual ~ParsingThread()
     {
@@ -202,11 +216,15 @@ OutputModelPrivate::OutputModelPrivate( OutputModel* model_, const QUrl& builddi
 {
     qRegisterMetaType<QVector<KDevelop::FilteredItem> >();
     qRegisterMetaType<KDevelop::IFilterStrategy*>();
+    qRegisterMetaType<KDevelop::IFilterStrategy::Progress>();
+
     s_parsingThread->addWorker(worker);
     model->connect(worker, &ParseWorker::parsedBatch,
                    model, [=] (const QVector<KDevelop::FilteredItem>& items) { linesParsed(items); });
     model->connect(worker, &ParseWorker::allDone,
                    model, &OutputModel::allDone);
+    model->connect(worker, &ParseWorker::progress,
+                   model, &OutputModel::progress);
 }
 
 bool OutputModelPrivate::isValidIndex( const QModelIndex& idx, int currentRowCount ) const
@@ -243,7 +261,7 @@ QVariant OutputModel::data(const QModelIndex& idx , int role ) const
         switch( role )
         {
             case Qt::DisplayRole:
-                return d->m_filteredItems.at( idx.row() ).shortenedText;
+                return d->m_filteredItems.at( idx.row() ).originalLine;
                 break;
             case OutputModel::OutputItemTypeRole:
                 return static_cast<int>(d->m_filteredItems.at( idx.row() ).type);
@@ -389,6 +407,12 @@ void OutputModel::setFilteringStrategy(const OutputFilterStrategy& currentStrate
                               Q_ARG(KDevelop::IFilterStrategy*, filter));
 }
 
+void OutputModel::setFilteringStrategy(IFilterStrategy* filterStrategy)
+{
+    QMetaObject::invokeMethod(d->worker, "changeFilterStrategy",
+                              Q_ARG(KDevelop::IFilterStrategy*, filterStrategy));
+}
+
 void OutputModel::appendLines( const QStringList& lines )
 {
     if( lines.isEmpty() )
