@@ -24,6 +24,7 @@
 
 #include "outputviewexport.h"
 #include "ioutputviewmodel.h"
+#include "ifilterstrategy.h"
 
 #include <QtCore/QAbstractListModel>
 #include <QUrl>
@@ -55,7 +56,7 @@ public:
 
     explicit OutputModel( const QUrl& builddir , QObject* parent = 0 );
     explicit OutputModel( QObject* parent = 0 );
-    virtual ~OutputModel();
+    ~OutputModel() override;
 
     /// IOutputViewModel interfaces
     void activate( const QModelIndex& index ) override;
@@ -68,6 +69,7 @@ public:
     QVariant headerData( int, Qt::Orientation, int = Qt::DisplayRole ) const override;
 
     void setFilteringStrategy(const OutputFilterStrategy& currentStrategy);
+    void setFilteringStrategy(IFilterStrategy* filterStrategy);
 
 public Q_SLOTS:
     void appendLine( const QString& );
@@ -75,6 +77,8 @@ public Q_SLOTS:
     void ensureAllDone();
 
 signals:
+    /// If the current filter strategy supports it, reports progress information
+    void progress(const KDevelop::IFilterStrategy::Progress& progress);
     void allDone();
 
 private:
