@@ -23,27 +23,29 @@
 #include <outputview/filtereditem.h>
 #include <language/interfaces/quickopenfilter.h>
 
-QTEST_GUILESS_MAIN(KDevelop::TestFilteringStrategy)
+using namespace KDevelop;
+
+QTEST_GUILESS_MAIN(TestFilteringStrategy)
 
 namespace QTest {
 
 template<>
-inline char* toString(const KDevelop::FilteredItem::FilteredOutputItemType& type)
+inline char* toString(const FilteredItem::FilteredOutputItemType& type)
 {
     switch (type) {
-        case KDevelop::FilteredItem::ActionItem:
+        case FilteredItem::ActionItem:
             return qstrdup("ActionItem");
-        case KDevelop::FilteredItem::CustomItem:
+        case FilteredItem::CustomItem:
             return qstrdup("CustomItem");
-        case KDevelop::FilteredItem::ErrorItem:
+        case FilteredItem::ErrorItem:
             return qstrdup("ErrorItem");
-        case KDevelop::FilteredItem::InformationItem:
+        case FilteredItem::InformationItem:
             return qstrdup("InformationItem");
-        case KDevelop::FilteredItem::InvalidItem:
+        case FilteredItem::InvalidItem:
             return qstrdup("InvalidItem");
-        case KDevelop::FilteredItem::StandardItem:
+        case FilteredItem::StandardItem:
             return qstrdup("StandardItem");
-        case KDevelop::FilteredItem::WarningItem:
+        case FilteredItem::WarningItem:
             return qstrdup("WarningItem");
     }
     return qstrdup("unknown");
@@ -51,9 +53,6 @@ inline char* toString(const KDevelop::FilteredItem::FilteredOutputItemType& type
 
 }
 
-namespace KDevelop
-{
-
 void TestFilteringStrategy::testNoFilterStrategy_data()
 {
     QTest::addColumn<QString>("line");
@@ -174,38 +173,6 @@ void TestFilteringStrategy::testCompilerFilterstrategyMultipleKeywords()
     QCOMPARE(item1.type, expectedAction);
 }
 
-void TestFilteringStrategy::testCompilerFilterStrategyShortenedText_data()
-{
-    QTest::addColumn<QString>("line");
-    QTest::addColumn<QString>("expectedShortenedText");
-
-    QTest::newRow("c++-compile")
-    << "g++ -c main.cpp -o main.o" << "compiling main.cpp (g++)";
-    QTest::newRow("clang++-link")
-    << "clang++ -c main.cpp -o main.o" << "compiling main.cpp (clang++)";
-    // see bug: https://bugs.kde.org/show_bug.cgi?id=240017
-    QTest::newRow("mpicc-link")
-    << "/usr/bin/mpicc -c main.cpp -o main.o" << "compiling main.cpp (mpicc)";
-
-    QTest::newRow("c++-link")
-    << "/usr/bin/g++ main.cpp -o main" << "linking main (g++)";
-    QTest::newRow("clang++-link")
-    << "/usr/bin/clang++ main.cpp -o a.out" << "linking a.out (clang++)";
-    QTest::newRow("mpicc-link")
-    << "mpicc main.cpp -o main" << "linking main (mpicc)";
-}
-
-void TestFilteringStrategy::testCompilerFilterStrategyShortenedText()
-{
-    QFETCH(QString, line);
-    QFETCH(QString, expectedShortenedText);
-
-    QUrl projecturl = QUrl::fromLocalFile( projectPath() );
-    CompilerFilterStrategy testee(projecturl);
-    FilteredItem item = testee.actionInLine(line);
-    QCOMPARE(item.shortenedText, expectedShortenedText);
-}
-
 void TestFilteringStrategy::testScriptErrorFilterStrategy_data()
 {
     QTest::addColumn<QString>("line");
@@ -246,6 +213,14 @@ void TestFilteringStrategy::testNativeAppErrorFilterStrategy_data()
     QTest::addColumn<int>("column");
     QTest::addColumn<FilteredItem::FilteredOutputItemType>("itemtype");
 
+    // BEGIN: C++
+    QTest::newRow("cassert")
+        << "a.out: /foo/bar/test.cpp:5: int main(): Assertion `false' failed."
+        << "/foo/bar/test.cpp"
+        << 4 << 0 << FilteredItem::ErrorItem;
+    // END: C++
+
+    // BEGIN: Qt
     // TODO: qt-connect-* and friends shouldn't be error items but warnings items instead
     // this needs refactoring in outputfilteringstrategies, though...
     QTest::newRow("qt-connect-nosuch-slot")
@@ -280,6 +255,19 @@ void TestFilteringStrategy::testNativeAppErrorFilterStrategy_data()
         << "   Loc: [Unknown file(0)]"
         << ""
         << -1 << -1 << FilteredItem::InvalidItem;
+    QTest::newRow("qml-import-unix")
+        << "file:///path/to/foo.qml:7:1: Bar is not a type"
+        << "/path/to/foo.qml"
+        << 6 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qml-import-unix1")
+        << "file:///path/to/foo.qml:7:1: Bar is ambiguous. Found in A and in B"
+        << "/path/to/foo.qml"
+        << 6 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("qml-import-unix2")
+        << "file:///path/to/foo.qml:7:1: Bar is instantiated recursively"
+        << "/path/to/foo.qml"
+        << 6 << 0 << FilteredItem::ErrorItem;
+    // END: Qt
 }
 
 void TestFilteringStrategy::testNativeAppErrorFilterStrategy()
@@ -349,15 +337,15 @@ void TestFilteringStrategy::testCompilerFilterstrategyUrlFromAction_data()
     QString basepath = projectPath();
 
     QTest::newRow("cmake-line1")
-    << "[ 25%] Building CXX object /path/to/one/CMakeFiles/file.o" << QString( basepath + "/path/to/one" );
+    << "[ 25%] Building CXX object path/to/one/CMakeFiles/file.o" << QString( basepath + "/path/to/one" );
     QTest::newRow("cmake-line2")
-    << "[ 26%] Building CXX object /path/to/two/CMakeFiles/file.o" << QString( basepath + "/path/to/two");
+    << "[ 26%] Building CXX object path/to/two/CMakeFiles/file.o" << QString( basepath + "/path/to/two");
     QTest::newRow("cmake-line3")
-    << "[ 26%] Building CXX object /path/to/three/CMakeFiles/file.o" << QString( basepath + "/path/to/three");
+    << "[ 26%] Building CXX object path/to/three/CMakeFiles/file.o" << QString( basepath + "/path/to/three");
     QTest::newRow("cmake-line4")
-    << "[ 26%] Building CXX object /path/to/four/CMakeFiles/file.o" << QString( basepath + "/path/to/four");
+    << "[ 26%] Building CXX object path/to/four/CMakeFiles/file.o" << QString( basepath + "/path/to/four");
     QTest::newRow("cmake-line5")
-    << "[ 26%] Building CXX object /path/to/two/CMakeFiles/file.o" << QString( basepath + "/path/to/two");
+    << "[ 26%] Building CXX object path/to/two/CMakeFiles/file.o" << QString( basepath + "/path/to/two");
     QTest::newRow("cd-line6")
     << QString("make[4]: Entering directory '" + basepath + "/path/to/one/'") << QString( basepath + "/path/to/one");
     QTest::newRow("waf-cd")
@@ -373,7 +361,8 @@ void TestFilteringStrategy::testCompilerFilterstrategyUrlFromAction()
     QUrl projecturl = QUrl::fromLocalFile( projectPath() );
     static CompilerFilterStrategy testee(projecturl);
     FilteredItem item1 = testee.actionInLine(line);
-    QCOMPARE(testee.getCurrentDirs().last(), expectedLastDir);
+    int last = testee.getCurrentDirs().size() - 1;
+    QCOMPARE(testee.getCurrentDirs().at(last), expectedLastDir);
 }
 
 void TestFilteringStrategy::benchMarkCompilerFilterAction()
@@ -407,7 +396,7 @@ void TestFilteringStrategy::benchMarkCompilerFilterAction()
     totalTime.start();
 
     static CompilerFilterStrategy testee(QUrl::fromLocalFile(projecturl));
-    FilteredItem item1("dummyline", FilteredItem::InvalidItem);
+    FilteredItem item1(QStringLiteral("dummyline"), FilteredItem::InvalidItem);
     QBENCHMARK {
         for(int i = 0; i < outputlines.size(); ++i) {
             item1 = testee.actionInLine(outputlines.at(i));
@@ -432,6 +421,14 @@ void TestFilteringStrategy::testExtractionOfLineAndColumn_data()
     QTest::addColumn<int>("column");
     QTest::addColumn<FilteredItem::FilteredOutputItemType>("itemtype");
 
+#ifdef Q_OS_WIN
+    QTest::newRow("msvc-compiler-error-line")
+        << "Z:\\kderoot\\download\\git\\kcoreaddons\\src\\lib\\jobs\\kjob.cpp(3): error C2065: 'dadsads': undeclared identifier"
+        << "Z:/kderoot/download/git/kcoreaddons/src/lib/jobs/kjob.cpp" << 2 << 0 << FilteredItem::ErrorItem;
+    QTest::newRow("msvc-compiler-warning-line")
+        << "c:\\program files\\microsoft visual studio 10.0\\vc\\include\\crtdefs.h(527): warning C4229: anachronism used : modifiers on data are ignored"
+        << "c:/program files/microsoft visual studio 10.0/vc/include/crtdefs.h" << 526 << 0 << FilteredItem::WarningItem;
+#else
     QTest::newRow("gcc-with-col")
         << "/path/to/file.cpp:123:45: fatal error: ..."
         << "/path/to/file.cpp" << 122 << 44 << FilteredItem::ErrorItem;
@@ -459,6 +456,7 @@ void TestFilteringStrategy::testExtractionOfLineAndColumn_data()
     QTest::newRow("gfortranError2")
         << "/path/flib.f90:3567.22:"
         << "/path/flib.f90" << 3566 << 21 << FilteredItem::ErrorItem;
+#endif
 }
 
 void TestFilteringStrategy::testExtractionOfLineAndColumn()
@@ -472,14 +470,7 @@ void TestFilteringStrategy::testExtractionOfLineAndColumn()
     CompilerFilterStrategy testee(projecturl);
     FilteredItem item1 = testee.errorInLine(line);
     QCOMPARE(item1.type , itemtype);
-    QCOMPARE(item1.url.path(), file);
+    QCOMPARE(KDevelop::toUrlOrLocalFile(item1.url), file);
     QCOMPARE(item1.lineNo , lineNr);
     QCOMPARE(item1.columnNo , column);
 }
-
-
-
-
-}
-
-
