@@ -8,8 +8,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#ifndef CVSGENERICOUTPUTVIEW_H
-#define CVSGENERICOUTPUTVIEW_H
+#ifndef KDEVPLATFORM_PLUGIN_CVSGENERICOUTPUTVIEW_H
+#define KDEVPLATFORM_PLUGIN_CVSGENERICOUTPUTVIEW_H
 
 #include <QWidget>
 #include <KJob>
@@ -31,15 +31,12 @@ class CvsJob;
 class CvsGenericOutputView : public QWidget, private Ui::CvsGenericOutputViewBase {
     Q_OBJECT
 public:
-    explicit CvsGenericOutputView(CvsPlugin *plugin, CvsJob* job=0, QWidget* parent=0);
-    virtual ~CvsGenericOutputView();
+    explicit CvsGenericOutputView(CvsJob* job = 0, QWidget* parent = 0);
+    ~CvsGenericOutputView() override;
 
 public slots:
     void appendText(const QString& text);
     void slotJobFinished(KJob* job);
-
-private:
-    CvsPlugin* m_plugin;
 };
 
 #endif
