@@ -1,6 +1,6 @@
 #include "grepfindthread.h"
+#include "debug.h"
 
-#include <KUrl>
 #include <QDir>
 #include <QSet>
 
@@ -9,22 +9,22 @@
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/icore.h>
 
-#include <language/duchain/indexedstring.h>
-#include <kdebug.h>
+#include <serialization/indexedstring.h>
+
 
 using KDevelop::IndexedString;
 
 /**
  * @return Return true in case @p url is in @p dir within a maximum depth of @p maxDepth
  */
-static bool isInDirectory(const KUrl& url, const KUrl& dir, int maxDepth)
+static bool isInDirectory(const QUrl& url, const QUrl& dir, int maxDepth)
 {
-    KUrl folderUrl = url.upUrl();
+    QUrl folderUrl = url.adjusted(QUrl::RemoveFilename);
 
     int currentLevel = maxDepth;
     while(currentLevel > 0) {
-        folderUrl = folderUrl.upUrl();
-        if ( folderUrl.equals(dir, KUrl::CompareWithoutTrailingSlash) ) {
+        folderUrl = folderUrl.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash);
+        if ( folderUrl == dir.adjusted(QUrl::StripTrailingSlash) ) {
             return true;
         }
         currentLevel--;
@@ -35,12 +35,12 @@ static bool isInDirectory(const KUrl& url, const KUrl& dir, int maxDepth)
 // the abort parameter must be volatile so that it
 // is evaluated every time - optimization might prevent that
 
-static KUrl::List thread_getProjectFiles(const KUrl dir, int depth, const QStringList include,
+static QList<QUrl> thread_getProjectFiles(const QUrl dir, int depth, const QStringList include,
                                          const QStringList exlude, volatile bool &abort)
 {
     ///@todo This is not thread-safe!
     KDevelop::IProject *project = KDevelop::ICore::self()->projectController()->findProjectForUrl( dir );
-    KUrl::List res;
+    QList<QUrl> res;
     if(!project)
         return res;
 
@@ -49,11 +49,11 @@ static KUrl::List thread_getProjectFiles(const KUrl dir, int depth, const QStrin
     {
         if(abort)
             break;
-        KUrl url = item.toUrl();
-        if( !url.equals(dir) )
+        QUrl url = item.toUrl();
+        if( url != dir )
         {
             if ( depth == 0 ) {
-                if ( !url.upUrl().equals(dir, KUrl::CompareWithoutTrailingSlash) ) {
+                if ( url.adjusted(QUrl::RemoveFilename | QUrl::StripTrailingSlash) != dir.adjusted(QUrl::StripTrailingSlash) ) {
                     continue;
                 }
             } else if ( !dir.isParentOf(url) ) {
@@ -74,20 +74,20 @@ static KUrl::List thread_getProjectFiles(const KUrl dir, int depth, const QStrin
     return res;
 }
 
-static KUrl::List thread_findFiles(const QDir& dir, int depth, const QStringList& include,
+static QList<QUrl> thread_findFiles(const QDir& dir, int depth, const QStringList& include,
                                    const QStringList& exclude, volatile bool &abort)
 {
     QFileInfoList infos = dir.entryInfoList(include, QDir::NoDotAndDotDot|QDir::Files|QDir::Readable);
-    
+
     if(!QFileInfo(dir.path()).isDir())
         infos << QFileInfo(dir.path());
-    
-    KUrl::List dirFiles;
+
+    QList<QUrl> dirFiles;
     foreach(const QFileInfo &currFile, infos)
     {
         QString currName = currFile.canonicalFilePath();
         if(!QDir::match(exclude, currName))
-            dirFiles << currName;
+            dirFiles << QUrl::fromLocalFile(currName);
     }
     if(depth != 0)
     {
@@ -97,7 +97,7 @@ static KUrl::List thread_findFiles(const QDir& dir, int depth, const QStringList
             if(abort)
                 break;
             QString canonical = currDir.canonicalFilePath();
-            if(!KUrl(dir.canonicalPath()).isParentOf(canonical))
+            if (!canonical.startsWith(dir.canonicalPath()))
                 continue;
 
             if ( depth > 0 ) {
@@ -111,7 +111,7 @@ static KUrl::List thread_findFiles(const QDir& dir, int depth, const QStringList
 }
 
 GrepFindFilesThread::GrepFindFilesThread(QObject* parent,
-                                         const QList<KUrl>& startDirs,
+                                         const QList<QUrl>& startDirs,
                                          int depth, const QString& pats,
                                          const QString& excl,
                                          bool onlyProject)
@@ -141,9 +141,9 @@ void GrepFindFilesThread::run()
     QStringList include = GrepFindFilesThread::parseInclude(m_patString);
     QStringList exclude = GrepFindFilesThread::parseExclude(m_exclString);
 
-    kDebug() << "running with start dir" << m_startDirs;
-    
-    foreach(KUrl directory, m_startDirs)
+    qCDebug(PLUGIN_GREPVIEW) << "running with start dir" << m_startDirs;
+
+    foreach(const QUrl& directory, m_startDirs)
     {
         if(m_project)
             m_files += thread_getProjectFiles(directory, m_depth, include, exclude, m_tryAbort);
@@ -152,12 +152,12 @@ void GrepFindFilesThread::run()
             m_files += thread_findFiles(directory.toLocalFile(), m_depth, include, exclude, m_tryAbort);
         }
     }
+
+    std::sort(m_files.end(), m_files.end());
 }
 
-KUrl::List GrepFindFilesThread::files() const {
-    KUrl::List tmpList = KUrl::List::fromSet(m_files.toSet());
-    qSort(tmpList);
-    return tmpList;
+QList<QUrl> GrepFindFilesThread::files() const {
+    return m_files;
 }
 
 QStringList GrepFindFilesThread::parseExclude(QString excl)
@@ -165,7 +165,7 @@ QStringList GrepFindFilesThread::parseExclude(QString excl)
     QStringList exclude;
     // Split around commas or spaces
     foreach(const QString &sub, excl.split(QRegExp(",|\\s"), QString::SkipEmptyParts))
-        exclude << QString("*%1*").arg(sub);
+        exclude << QStringLiteral("*%1*").arg(sub);
     return exclude;
 }
 
