@@ -196,8 +196,12 @@ void PatchReviewPlugin::removeHighlighting( const QUrl& file ) {
 }
 
 void PatchReviewPlugin::notifyPatchChanged() {
-    qCDebug(PLUGIN_PATCHREVIEW) << "notifying patch change: " << m_patch->file();
-    m_updateKompareTimer->start( 500 );
+    if (m_patch) {
+        qCDebug(PLUGIN_PATCHREVIEW) << "notifying patch change: " << m_patch->file();
+        m_updateKompareTimer->start( 500 );
+    } else {
+        m_updateKompareTimer->stop();
+    }
 }
 
 void PatchReviewPlugin::forceUpdate() {
@@ -290,16 +294,16 @@ class PatchReviewToolViewFactory : public KDevelop::IToolViewFactory
 public:
     PatchReviewToolViewFactory( PatchReviewPlugin *plugin ) : m_plugin( plugin ) {}
 
-    virtual QWidget* create( QWidget *parent = 0 ) override {
+    QWidget* create( QWidget *parent = 0 ) override {
         return m_plugin->createToolView( parent );
     }
 
-    virtual Qt::DockWidgetArea defaultPosition() override {
+    Qt::DockWidgetArea defaultPosition() override {
         return Qt::BottomDockWidgetArea;
     }
 
-    virtual QString id() const override {
-        return "org.kdevelop.PatchReview";
+    QString id() const override {
+        return QStringLiteral("org.kdevelop.PatchReview");
     }
 
 private:
@@ -312,9 +316,8 @@ PatchReviewPlugin::~PatchReviewPlugin()
 
     // Tweak to work around a crash on OS X; see https://bugs.kde.org/show_bug.cgi?id=338829
     // and http://qt-project.org/forums/viewthread/38406/#162801
-    if (m_patch) {
-        m_patch->deleteLater();
-    }
+    // modified tweak: use setPatch() and deleteLater in that method.
+    setPatch(0);
 }
 
 void PatchReviewPlugin::clearPatch( QObject* _patch ) {
@@ -340,9 +343,9 @@ void PatchReviewPlugin::closeReview()
             emit patchChanged();
 
         Sublime::MainWindow* w = dynamic_cast<Sublime::MainWindow*>( ICore::self()->uiController()->activeMainWindow() );
-        if( w->area()->objectName() == "review" ) {
-            if( ICore::self()->documentController()->closeAllDocuments() )
-                ICore::self()->uiController()->switchToArea( "code", KDevelop::IUiController::ThisWindow );
+        if( w->area()->objectName() == QLatin1String("review") ) {
+            if( ICore::self()->documentController()->saveAllDocuments() )
+                ICore::self()->uiController()->switchToArea( QStringLiteral("code"), KDevelop::IUiController::ThisWindow );
         }
     }
 }
@@ -370,13 +373,13 @@ void PatchReviewPlugin::startReview( IPatchSource* patch, IPatchReview::ReviewMo
 void PatchReviewPlugin::switchToEmptyReviewArea()
 {
     foreach(Sublime::Area* area, ICore::self()->uiController()->allAreas()) {
-        if (area->objectName() == "review") {
+        if (area->objectName() == QLatin1String("review")) {
             emit area->clearDocuments();
         }
     }
 
-    if ( ICore::self()->uiController()->activeArea()->objectName() != "review" )
-        ICore::self()->uiController()->switchToArea( "review", KDevelop::IUiController::ThisWindow );
+    if ( ICore::self()->uiController()->activeArea()->objectName() != QLatin1String("review") )
+        ICore::self()->uiController()->switchToArea( QStringLiteral("review"), KDevelop::IUiController::ThisWindow );
 }
 
 QUrl PatchReviewPlugin::urlForFileModel( const Diff2::DiffModel* model )
@@ -416,9 +419,9 @@ void PatchReviewPlugin::updateReview()
         for( int a = 0; a < m_modelList->modelCount(); ++a ) {
             QUrl absoluteUrl = urlForFileModel( m_modelList->modelAt( a ) );
 
-            if( QFileInfo( absoluteUrl.toLocalFile() ).exists() && absoluteUrl.toLocalFile() != "/dev/null" )
+            if( QFileInfo::exists( absoluteUrl.toLocalFile() ) && absoluteUrl.toLocalFile() != QLatin1String("/dev/null") )
             {
-                buddyDoc = ICore::self()->documentController()->openDocument( absoluteUrl, KTextEditor::Range::invalid(), IDocumentController::DoNotActivate, "", buddyDoc );
+                buddyDoc = ICore::self()->documentController()->openDocument( absoluteUrl, KTextEditor::Range::invalid(), IDocumentController::DoNotActivate, QLatin1String(""), buddyDoc );
 
                 seekHunk( true, absoluteUrl ); //Jump to the first changed position
             }else{
@@ -446,7 +449,7 @@ void PatchReviewPlugin::setPatch( IPatchSource* patch ) {
         if ( qobject_cast<LocalPatchSource*>( m_patch ) ) {
             // make sure we don't leak this
             // TODO: what about other patch sources?
-            delete m_patch;
+            m_patch->deleteLater();
         }
     }
     m_patch = patch;
@@ -465,12 +468,12 @@ void PatchReviewPlugin::setPatch( IPatchSource* patch ) {
 }
 
 PatchReviewPlugin::PatchReviewPlugin( QObject *parent, const QVariantList & )
-    : KDevelop::IPlugin( "kdevpatchreview", parent ),
+    : KDevelop::IPlugin( QStringLiteral("kdevpatchreview"), parent ),
     m_patch( 0 ), m_factory( new PatchReviewToolViewFactory( this ) ) {
     KDEV_USE_EXTENSION_INTERFACE( KDevelop::IPatchReview )
     qRegisterMetaType<const Diff2::DiffModel*>( "const Diff2::DiffModel*" );
 
-    setXMLFile( "kdevpatchreview.rc" );
+    setXMLFile( QStringLiteral("kdevpatchreview.rc") );
 
     connect( ICore::self()->documentController(), &IDocumentController::documentClosed, this, &PatchReviewPlugin::documentClosed );
     connect( ICore::self()->documentController(), &IDocumentController::textDocumentCreated, this, &PatchReviewPlugin::textDocumentCreated );
@@ -481,12 +484,12 @@ PatchReviewPlugin::PatchReviewPlugin( QObject *parent, const QVariantList & )
     connect( m_updateKompareTimer, &QTimer::timeout, this, &PatchReviewPlugin::updateKompareModel );
 
     m_finishReview = new QAction(i18n("Finish Review"), this);
-    m_finishReview->setIcon( QIcon::fromTheme( "dialog-ok" ) );
+    m_finishReview->setIcon( QIcon::fromTheme( QStringLiteral("dialog-ok") ) );
     actionCollection()->setDefaultShortcut( m_finishReview, Qt::CTRL|Qt::Key_Return );
-    actionCollection()->addAction("commit_or_finish_review", m_finishReview);
+    actionCollection()->addAction(QStringLiteral("commit_or_finish_review"), m_finishReview);
 
     foreach(Sublime::Area* area, ICore::self()->uiController()->allAreas()) {
-        if (area->objectName() == "review")
+        if (area->objectName() == QLatin1String("review"))
             area->addAction(m_finishReview);
     }
 
@@ -525,7 +528,7 @@ QWidget* PatchReviewPlugin::createToolView( QWidget* parent ) {
 
 void PatchReviewPlugin::areaChanged(Sublime::Area* area)
 {
-    bool reviewing = area->objectName() == "review";
+    bool reviewing = area->objectName() == QLatin1String("review");
     m_finishReview->setEnabled(reviewing);
     if(!reviewing) {
         closeReview();
