@@ -67,12 +67,7 @@ using namespace KDevelop;
 class ProblemReporterFactory : public KDevelop::IToolViewFactory
 {
 public:
-    ProblemReporterFactory(ProblemReporterPlugin* plugin)
-        : m_plugin(plugin)
-    {
-    }
-
-    virtual QWidget* create(QWidget* parent = 0) override
+    QWidget* create(QWidget* parent = 0) override
     {
         Q_UNUSED(parent);
 
@@ -81,23 +76,20 @@ public:
         return v;
     }
 
-    virtual Qt::DockWidgetArea defaultPosition() override { return Qt::BottomDockWidgetArea; }
+    Qt::DockWidgetArea defaultPosition() override { return Qt::BottomDockWidgetArea; }
 
-    virtual QString id() const override { return "org.kdevelop.ProblemReporterView"; }
-
-private:
-    ProblemReporterPlugin* m_plugin;
+    QString id() const override { return QStringLiteral("org.kdevelop.ProblemReporterView"); }
 };
 
 ProblemReporterPlugin::ProblemReporterPlugin(QObject* parent, const QVariantList&)
-    : KDevelop::IPlugin("kdevproblemreporter", parent)
-    , m_factory(new ProblemReporterFactory(this))
+    : KDevelop::IPlugin(QStringLiteral("kdevproblemreporter"), parent)
+    , m_factory(new ProblemReporterFactory)
     , m_model(new ProblemReporterModel(this))
 {
     KDevelop::ProblemModelSet* pms = core()->languageController()->problemModelSet();
-    pms->addModel("Parser", m_model);
+    pms->addModel(QStringLiteral("Parser"), m_model);
     core()->uiController()->addToolView(i18n("Problems"), m_factory);
-    setXMLFile("kdevproblemreporter.rc");
+    setXMLFile(QStringLiteral("kdevproblemreporter.rc"));
 
     connect(ICore::self()->documentController(), &IDocumentController::documentClosed, this,
             &ProblemReporterPlugin::documentClosed);
@@ -120,7 +112,7 @@ ProblemReporterModel* ProblemReporterPlugin::model() const
 void ProblemReporterPlugin::unload()
 {
     KDevelop::ProblemModelSet* pms = KDevelop::ICore::self()->languageController()->problemModelSet();
-    pms->removeModel("Parser");
+    pms->removeModel(QStringLiteral("Parser"));
 
     core()->uiController()->removeToolView(m_factory);
 }
