@@ -38,7 +38,7 @@ class VcsOverlayProxyModel : public QIdentityProxyModel
         };
         explicit VcsOverlayProxyModel(QObject* parent = 0);
 
-        virtual QVariant data(const QModelIndex& proxyIndex, int role = Qt::DisplayRole) const override;
+        QVariant data(const QModelIndex& proxyIndex, int role = Qt::DisplayRole) const override;
 
     private slots:
         void addProject(KDevelop::IProject* p);
