@@ -31,10 +31,11 @@ namespace KDevelop { class IProject; }
 
 class WelcomePageView : public Sublime::View
 {
+    Q_OBJECT
     public:
         explicit WelcomePageView(Sublime::Document* doc, WidgetOwnership ws = DoNotTakeOwnerShip);
 
-        virtual QWidget* createWidget(QWidget* parent) override;
+        QWidget* createWidget(QWidget* parent) override;
 };
 
 
