@@ -21,17 +21,20 @@
 
 #include "assistantpopup.h"
 #include "sublime/holdupdates.h"
+#include "util/kdevstringhandler.h"
 
+#include <QAction>
+#include <QApplication>
 #include <QKeyEvent>
 #include <QDebug>
+#include <QEvent>
 #include <QTimer>
-#include <QDeclarativeContext>
+#include <QStandardPaths>
+#include <QQmlContext>
+#include <QQuickItem>
 
 #include <KLocalizedString>
-#include <KAction>
 #include <KParts/MainWindow>
-#include <KStandardDirs>
-#include <KTextEditor/HighlightInterface>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 #include <KTextEditor/ConfigInterface>
@@ -45,10 +48,6 @@ using namespace KDevelop;
 
 namespace {
 
-/// Interval after which the state of the popup is re-evaluated
-/// Used to avoid flickering caused when user is quickly inserting code
-const int UPDATE_STATE_INTERVAL = 300; // ms
-
 const int ASSISTANT_MODIFIER =
 #ifdef Q_OS_MAC
 Qt::CTRL;
@@ -66,7 +65,7 @@ Qt::Key_Alt;
 QWidget* findByClassname(const KTextEditor::View* view, const QString& klass)
 {
     auto children = view->findChildren<QWidget*>();
-    for ( auto child: children ) {
+    foreach ( auto child, children ) {
         if ( child->metaObject()->className() == klass ) {
             return child;
         }
@@ -81,12 +80,12 @@ QRect textWidgetGeometry(const KTextEditor::View *view)
 {
     // Subtract the width of the right scrollbar
     int scrollbarWidth = 0;
-    if ( auto scrollbar = findByClassname(view, "KateScrollBar") ) {
+    if ( auto scrollbar = findByClassname(view, QStringLiteral("KateScrollBar")) ) {
         scrollbarWidth = scrollbar->width();
     }
     // Subtract the width of the bottom scrollbar
     int bottomScrollbarWidth = 0;
-    if ( auto bottom = findByClassname(view, "QScrollBar") ) {
+    if ( auto bottom = findByClassname(view, QStringLiteral("QScrollBar")) ) {
         bottomScrollbarWidth = bottom->height();
     }
     auto geom = view->geometry();
@@ -107,9 +106,9 @@ void AssistantPopupConfig::setColorsFromView(QObject *view)
 {
     auto iface = dynamic_cast<KTextEditor::ConfigInterface*>(view);
     Q_ASSERT(iface);
-    m_foreground = iface->configValue("line-number-color").value<QColor>();
-    m_background = iface->configValue("icon-border-color").value<QColor>();
-    m_highlight = iface->configValue("folding-marker-color").value<QColor>();
+    m_foreground = iface->configValue(QStringLiteral("line-number-color")).value<QColor>();
+    m_background = iface->configValue(QStringLiteral("icon-border-color")).value<QColor>();
+    m_highlight = iface->configValue(QStringLiteral("folding-marker-color")).value<QColor>();
     if ( KColorUtils::luma(m_background) < 0.3 ) {
         m_foreground = KColorUtils::lighten(m_foreground, 0.7);
     }
@@ -138,6 +137,14 @@ void AssistantPopupConfig::setActive(bool active)
     emit activeChanged(m_active);
 }
 
+void AssistantPopupConfig::setViewSize(const QSize& size)
+{
+    if (size != m_viewSize) {
+        m_viewSize = size;
+        emit viewSizeChanged(size);
+    }
+}
+
 void AssistantPopupConfig::setTitle(const QString& title)
 {
     if (m_title == title) {
@@ -161,43 +168,35 @@ void AssistantPopupConfig::setModel(const QList<QObject*>& model)
 
 AssistantPopup::AssistantPopup()
 // main window as parent to use maximal space available in worst case
-    : QDeclarativeView(ICore::self()->uiController()->activeMainWindow())
+    : QQuickWidget(ICore::self()->uiController()->activeMainWindow())
     , m_config(new AssistantPopupConfig(this))
-    , m_shownAtBottom(false)
-    , m_reopening(false)
-    , m_updateTimer(new QTimer(this))
+    , m_firstLayoutCompleted(false)
 {
-    QPalette p = palette();
-    p.setColor(QPalette::Window, Qt::transparent);
-    setPalette(p);
-    setBackgroundRole(QPalette::Window);
-    setBackgroundBrush(QBrush(QColor(0, 0, 0, 0)));
-    setResizeMode(QDeclarativeView::SizeViewToRootObject);
     setAttribute(Qt::WA_ShowWithoutActivating);
 
-    rootContext()->setContextProperty("config", m_config);
+    rootContext()->setContextProperty(QStringLiteral("config"), m_config);
 
-    setSource(QUrl::fromLocalFile(KStandardDirs::locate("data", "kdevelop/assistantpopup.qml")));
+    setSource(QUrl::fromLocalFile(QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kdevelop/assistantpopup.qml"))));
     if (!rootObject()) {
-        kWarning() << "Failed to load assistant markup! The assistant will not work.";
+        qWarning() << "Failed to load assistant markup! The assistant will not work.";
+    } else {
+        connect(rootObject(), &QQuickItem::widthChanged, this, &AssistantPopup::updateLayout);
+        connect(rootObject(), &QQuickItem::heightChanged, this, &AssistantPopup::updateLayout);
     }
 
-    m_updateTimer->setInterval(UPDATE_STATE_INTERVAL);
-    m_updateTimer->setSingleShot(true);
-    connect(m_updateTimer, SIGNAL(timeout()), this, SLOT(updateState()));
-
     for (int i = Qt::Key_0; i <= Qt::Key_9; ++i) {
         m_shortcuts.append(new QShortcut(ASSISTANT_MODIFIER + i, this));
     }
     setActive(false);
+
+    connect(qApp, &QApplication::applicationStateChanged, this, [this]{ setActive(false); });
 }
 
 void AssistantPopup::reset(KTextEditor::View* view, const IAssistant::Ptr& assistant)
 {
     setView(view);
     setAssistant(assistant);
-
-    m_updateTimer->start();
+    updateState();
 }
 
 void AssistantPopup::setView(KTextEditor::View* view)
@@ -210,14 +209,15 @@ void AssistantPopup::setView(KTextEditor::View* view)
 
     if (m_view) {
         m_view->removeEventFilter(this);
-        disconnect(m_view, SIGNAL(verticalScrollPositionChanged(KTextEditor::View*,KTextEditor::Cursor)),
-                  this, SLOT(updatePosition(KTextEditor::View*,KTextEditor::Cursor)));
+        disconnect(m_view.data(), &KTextEditor::View::verticalScrollPositionChanged,
+                  this, &AssistantPopup::updatePosition);
     }
     m_view = view;
+    m_config->setViewSize(m_view ? m_view->size() : QSize());
     if (m_view) {
         m_view->installEventFilter(this);
-        connect(m_view, SIGNAL(verticalScrollPositionChanged(KTextEditor::View*,KTextEditor::Cursor)),
-                this, SLOT(updatePosition(KTextEditor::View*,KTextEditor::Cursor)));
+        connect(m_view.data(), &KTextEditor::View::verticalScrollPositionChanged,
+                this, &AssistantPopup::updatePosition);
     }
 }
 
@@ -228,46 +228,35 @@ void AssistantPopup::setAssistant(const IAssistant::Ptr& assistant)
     }
 
     if (m_assistant) {
-        disconnect(m_assistant.data(), SIGNAL(actionsChanged()), m_updateTimer, SLOT(start()));
-        disconnect(m_assistant.data(), SIGNAL(hide()), this, SLOT(hideAssistant()));
+        disconnect(m_assistant.data(), &IAssistant::hide, this, &AssistantPopup::hideAssistant);
+        disconnect(m_assistant.data(), &IAssistant::actionsChanged, this, &AssistantPopup::updateState);
     }
     m_assistant = assistant;
     if (m_assistant) {
-        connect(m_assistant.data(), SIGNAL(actionsChanged()), m_updateTimer, SLOT(start()));
-        connect(m_assistant.data(), SIGNAL(hide()), this, SLOT(hideAssistant()));
+        connect(m_assistant.data(), &IAssistant::hide, this, &AssistantPopup::hideAssistant);
+        connect(m_assistant.data(), &IAssistant::actionsChanged, this, &AssistantPopup::updateState);
+    } else {
+        hide();
     }
 }
 
 void AssistantPopup::setActive(bool active)
 {
     m_config->setActive(active);
-    for (auto shortcut : m_shortcuts) {
+    foreach (auto shortcut, m_shortcuts) {
         shortcut->setEnabled(active);
     }
 }
 
-bool AssistantPopup::viewportEvent(QEvent *event)
-{
-    // For some reason, QGraphicsView posts a WindowActivate event
-    // when it is shown, even if disabled through setting the WA_ShowWithoutActivate
-    // attribute. This causes all focus-driven popups (QuickOpen, tooltips, ...)
-    // to hide when the assistant opens. Thus, prevent it from processing the Show event here.
-    if ( event->type() == QEvent::Show ) {
-        return true;
-    }
-    return QGraphicsView::viewportEvent(event);
-}
-
 bool AssistantPopup::eventFilter(QObject* object, QEvent* event)
 {
-    if (!m_view)
-        return false;
-
-    Q_ASSERT(object == m_view.data());
     Q_UNUSED(object);
 
+    if (!m_view || (object != m_view.data()))
+        return false;
+
     if (event->type() == QEvent::Resize) {
-        updatePosition(m_view.data(), KTextEditor::Cursor::invalid());
+        updateLayout();
     } else if (event->type() == QEvent::Hide) {
         executeHideAction();
     } else if (event->type() == QEvent::KeyPress) {
@@ -291,7 +280,7 @@ void AssistantPopup::updatePosition(KTextEditor::View* view, const KTextEditor::
 {
     static const int MARGIN = 12;
 
-    if (newPos.isValid() && newPos.line() == 0 && !m_shownAtBottom) {
+    if (newPos.isValid() && newPos.line() == 0) {
         // the position is not going to change; don't waste time
         return;
     }
@@ -315,15 +304,8 @@ void AssistantPopup::updatePosition(KTextEditor::View* view, const KTextEditor::
         return;
     }
 
-    if ( m_reopening ) {
-        // When the assistant is already visible, close to no flickering will occur anyways,
-        // so we can avoid the full repaint of the window.
-        move(targetLocation);
-    }
-    else {
-        Sublime::HoldUpdates hold(ICore::self()->uiController()->activeMainWindow());
-        move(targetLocation);
-    }
+    Sublime::HoldUpdates hold(ICore::self()->uiController()->activeMainWindow());
+    move(targetLocation);
 }
 
 IAssistant::Ptr AssistantPopup::assistant() const
@@ -343,41 +325,56 @@ void AssistantPopup::hideAssistant()
     reset(nullptr, {}); // indirectly calls hide()
 }
 
+void AssistantPopup::updateLayout()
+{
+    if ( !m_view ) {
+        return;
+    }
+
+    m_config->setViewSize(m_view->size());
+    // https://bugreports.qt.io/browse/QTBUG-44876
+    resize(rootObject()->width(), rootObject()->height());
+    updatePosition(m_view, KTextEditor::Cursor::invalid());
+
+    // HACK: QQuickWidget is corrupted due to above resize on the first show
+    if (!m_firstLayoutCompleted) {
+        hide();
+        show();
+        m_firstLayoutCompleted = true;
+    }
+}
+
 void AssistantPopup::updateState()
 {
-    if (!m_assistant || m_assistant->actions().isEmpty()) {
+    if (!m_assistant || m_assistant->actions().isEmpty() || !m_view) {
         hide();
         return;
     }
 
     auto curShortcut = m_shortcuts.constBegin();
-    auto hideAction = new KAction(i18n("Hide"), this);
-    connect(*curShortcut, SIGNAL(activated()), hideAction, SLOT(trigger()));
-    connect(hideAction, SIGNAL(triggered()), this, SLOT(executeHideAction()));
+    auto hideAction = new QAction(i18n("Hide"), this);
+    connect(*curShortcut, &QShortcut::activated, hideAction, &QAction::trigger);
+    connect(hideAction, &QAction::triggered, this, &AssistantPopup::executeHideAction);
 
     QList<QObject*> items;
     foreach (IAssistantAction::Ptr action, m_assistant->actions()) {
-        items << action->toKAction();
-        items.last()->setParent(this);
-        //For some reason, KAction's setShortcut does nothing, so we manage with QShortcut
+        QAction* asQAction = action->toKAction();
+        items << asQAction;
+        asQAction->setParent(this);
+        //For some reason, QAction's setShortcut does nothing, so we manage with QShortcut
         if (++curShortcut != m_shortcuts.constEnd()) {
-            connect(*curShortcut, SIGNAL(activated()), items.last(), SLOT(trigger()));
+            connect(*curShortcut, &QShortcut::activated, asQAction, &QAction::trigger);
         }
+        connect(action.data(), SIGNAL(executed(IAssistantAction*)), hideAction, SLOT(trigger()));
     }
     items << hideAction;
 
-    auto doc = ICore::self()->documentController()->activeDocument();
-    m_config->setColorsFromView(doc->textDocument()->activeView());
+    auto view = ICore::self()->documentController()->activeTextDocumentView();
+    m_config->setColorsFromView(view);
     m_config->setModel(items);
     m_config->setTitle(m_assistant->title());
     setActive(false);
 
-    // both changed title or actions may change the appearance of the popup
-    // force recomputing the size hint
-    resize(sizeHint());
-    updatePosition(m_view, KTextEditor::Cursor::invalid());
-
     show();
 }
 
-#include "assistantpopup.moc"
