@@ -69,10 +69,9 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
     mainLayout->setContentsMargins( 0, 0, 0, 0 );
     splitter->setSizes(QList<int>() << 260 << 620);
 
-    addConfig->setIcon( QIcon::fromTheme("list-add") );
-    addConfig->setEnabled( false );
+    addConfig->setIcon( QIcon::fromTheme(QStringLiteral("list-add")) );
     addConfig->setToolTip(i18nc("@info:tooltip", "Add a new launch configuration."));
-    deleteConfig->setIcon( QIcon::fromTheme("list-remove") );
+    deleteConfig->setIcon( QIcon::fromTheme(QStringLiteral("list-remove")) );
     deleteConfig->setEnabled( false );
     deleteConfig->setToolTip(i18nc("@info:tooltip", "Delete selected launch configuration."));
 
@@ -82,7 +81,7 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
     tree->setSelectionBehavior( QAbstractItemView::SelectRows );
     tree->setSelectionMode( QAbstractItemView::SingleSelection );
     tree->setUniformRowHeights( true );
-    tree->setItemDelegate( new LaunchConfigurationModelDelegate() );
+    tree->setItemDelegate( new LaunchConfigurationModelDelegate(this) );
     tree->setColumnHidden(1, true);
     for(int row=0; row<model->rowCount(); row++) {
         tree->setExpanded(model->index(row, 0), true);
@@ -159,7 +158,7 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
     }
     // Simplify menu structure to get rid of 1-entry levels
     while (m->actions().count() == 1) {
-        QMenu* subMenu = m->actions().first()->menu();
+        QMenu* subMenu = m->actions().at(0)->menu();
         if (subMenu && subMenu->isEnabled() && subMenu->actions().count()<5) {
             m = subMenu;
         } else {
@@ -169,7 +168,7 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
     if(!m->isEmpty()) {
         QAction* separator = new QAction(m);
         separator->setSeparator(true);
-        m->insertAction(m->actions().first(), separator);
+        m->insertAction(m->actions().at(0), separator);
     }
 
     foreach(LaunchConfigurationType* type, types) {
@@ -178,11 +177,17 @@ LaunchConfigurationDialog::LaunchConfigurationDialog(QWidget* parent)
         connect(action, &QAction::triggered, this, &LaunchConfigurationDialog::createEmptyLauncher);
 
         if(!m->actions().isEmpty())
-            m->insertAction(m->actions().first(), action);
+            m->insertAction(m->actions().at(0), action);
         else
             m->addAction(action);
     }
     addConfig->setMenu(m);
+    addConfig->setEnabled( !m->isEmpty() );
+
+    messageWidget->setCloseButtonVisible( false );
+    messageWidget->setMessageType( KMessageWidget::Warning );
+    messageWidget->setText( i18n("No launch configurations available. (Is any of the Execute plugins loaded?)") );
+    messageWidget->setVisible( m->isEmpty() );
 
     connect(debugger, static_cast<void(QComboBox::*)(int)>(&QComboBox::currentIndexChanged), this, &LaunchConfigurationDialog::launchModeChanged);
 
@@ -202,8 +207,8 @@ void LaunchConfigurationDialog::doTreeContextMenu(QPoint point)
         if ( selected.parent().isValid() && ! selected.parent().parent().isValid() ) {
             // only display the menu if a launch config is clicked
             QMenu menu;
-            QAction* rename = new QAction(QIcon::fromTheme("edit-rename"), i18n("Rename configuration"), &menu);
-            QAction* delete_ = new QAction(QIcon::fromTheme("edit-delete"), i18n("Delete configuration"), &menu);
+            QAction* rename = new QAction(QIcon::fromTheme(QStringLiteral("edit-rename")), i18n("Rename configuration"), &menu);
+            QAction* delete_ = new QAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Delete configuration"), &menu);
             connect(rename, &QAction::triggered, this, &LaunchConfigurationDialog::renameSelected);
             connect(delete_, &QAction::triggered, this, &LaunchConfigurationDialog::deleteConfiguration);
             menu.addAction(rename);
@@ -361,14 +366,14 @@ void LaunchConfigurationDialog::selectionChanged(QItemSelection selected, QItemS
                 tab->setLaunchConfiguration( l );
                 stack->setCurrentWidget( tab );
 
-                addConfig->setEnabled( true );
+                addConfig->setEnabled( addConfig->menu() && !addConfig->menu()->isEmpty() );
                 deleteConfig->setEnabled( true );
                 debugger->setVisible( false );
                 debugLabel->setVisible( false );
             }
         } else
         {
-            addConfig->setEnabled( true );
+            addConfig->setEnabled( addConfig->menu() && !addConfig->menu()->isEmpty() );
             deleteConfig->setEnabled( false );
             stack->setCurrentIndex( 0 );
             QLabel* l = new QLabel(i18n("<i>Select a configuration to edit from the left,<br>"
@@ -622,10 +627,10 @@ QVariant LaunchConfigurationsModel::data(const QModelIndex& index, int role) con
                 if ( index.column() == 0 && !index.parent().isValid() ) {
                     if (index.row() == 0) {
                         // global item
-                        return QIcon::fromTheme("folder");
+                        return QIcon::fromTheme(QStringLiteral("folder"));
                     } else {
                         // project item
-                        return QIcon::fromTheme("folder-development");
+                        return QIcon::fromTheme(QStringLiteral("folder-development"));
                     }
                 }
             }
@@ -977,10 +982,6 @@ QWidget* LaunchConfigurationModelDelegate::createEditor ( QWidget* parent, const
     return QStyledItemDelegate::createEditor ( parent, option, index );
 }
 
-LaunchConfigurationModelDelegate::LaunchConfigurationModelDelegate()
-{
-}
-
 void LaunchConfigurationModelDelegate::setEditorData ( QWidget* editor, const QModelIndex& index ) const
 {
     const LaunchConfigurationsModel* model = dynamic_cast<const LaunchConfigurationsModel*>( index.model() );
