@@ -252,11 +252,11 @@ public:
 PluginController::PluginController(Core *core)
     : IPluginController(), d(new PluginControllerPrivate)
 {
-    setObjectName("PluginController");
+    setObjectName(QStringLiteral("PluginController"));
     d->core = core;
 
     QSet<QString> foundPlugins;
-    auto newPlugins = KPluginLoader::findPlugins("kdevplatform/" QT_STRINGIFY(KDEVELOP_PLUGIN_VERSION), [&](const KPluginMetaData& meta) {
+    auto newPlugins = KPluginLoader::findPlugins(QStringLiteral("kdevplatform/" QT_STRINGIFY(KDEVELOP_PLUGIN_VERSION)), [&](const KPluginMetaData& meta) {
         if (meta.serviceTypes().contains(QStringLiteral("KDevelop/Plugin"))) {
             foundPlugins.insert(meta.pluginId());
             return true;
@@ -266,16 +266,15 @@ PluginController::PluginController(Core *core)
             return false;
         }
     });
+
     qCDebug(SHELL) << "Found" << newPlugins.size() << " plugins:" << foundPlugins;
+
     d->plugins = newPlugins;
 
     KTextEditorIntegration::initialize();
     const QVector<KPluginMetaData> katePlugins = KPluginLoader::findPlugins(QStringLiteral("ktexteditor"), [](const KPluginMetaData & md) {
-        static const QVector<QString> whiteListedPlugins = {
-            QStringLiteral("katesnippetsplugin")
-        };
         return md.serviceTypes().contains(QStringLiteral("KTextEditor/Plugin"))
-            && whiteListedPlugins.contains(md.pluginId());
+            && md.serviceTypes().contains(QStringLiteral("KDevelop/Plugin"));
     });
     foreach (const auto& info, katePlugins) {
         auto data = info.rawData();
@@ -500,7 +499,7 @@ IPlugin *PluginController::loadPluginInternal( const QString &pluginId )
     if ( !hasUnresolvedDependencies( info, missingInterfaces ) ) {
         qWarning() << "Can't load plugin" << pluginId
                    << "some of its required dependencies could not be fulfilled:"
-                   << missingInterfaces.join(",");
+                   << missingInterfaces.join(QStringLiteral(","));
         return nullptr;
     }
 
