@@ -70,6 +70,7 @@ Boston, MA 02110-1301, USA.
 #include <vcs/widgets/vcscommitdialog.h>
 
 #include "core.h"
+// TODO: Should get rid off this include (should depend on IProject only)
 #include "project.h"
 #include "mainwindow.h"
 #include "shellextension.h"
@@ -137,7 +138,7 @@ public:
         options.projectTempFile = proj->projectTempFile();
         options.project = proj;
 
-        for (IPlugin* plugin : findPluginsForProject(proj)) {
+        foreach (IPlugin* plugin, findPluginsForProject(proj)) {
             for (int i = 0; i < plugin->perProjectConfigPages(); ++i) {
                 configPages.append(plugin->perProjectConfigPage(i, options, mainWindow));
             }
@@ -199,7 +200,7 @@ public:
             collectBuilders( buildersForKcm, buildSystemManager->builder(), project );
         }
 
-        for(auto plugin : plugins) {
+        foreach(auto plugin, plugins) {
             auto info = m_core->pluginController()->pluginInfo(plugin);
             IProjectFileManager* manager = plugin->extension<KDevelop::IProjectFileManager>();
             if( manager && manager != project->projectFileManager() )
@@ -310,8 +311,8 @@ public:
 
     void areaChanged(Sublime::Area* area) {
         KActionCollection* ac = m_core->uiControllerInternal()->defaultMainWindow()->actionCollection();
-        ac->action("commit_current_project")->setEnabled(area->objectName() == "code");
-        ac->action("commit_current_project")->setVisible(area->objectName() == "code");
+        ac->action(QStringLiteral("commit_current_project"))->setEnabled(area->objectName() == QLatin1String("code"));
+        ac->action(QStringLiteral("commit_current_project"))->setVisible(area->objectName() == QLatin1String("code"));
     }
 };
 
@@ -366,7 +367,7 @@ bool projectFileExists( const QUrl& u )
 {
     if( u.isLocalFile() )
     {
-        return QFileInfo( u.toLocalFile() ).exists();
+        return QFileInfo::exists( u.toLocalFile() );
     } else
     {
         auto statJob = KIO::stat(u, KIO::StatJob::DestinationSide, 0);
@@ -474,7 +475,7 @@ ProjectController::ProjectController( Core* core )
 {
     qRegisterMetaType<QList<QUrl>>();
 
-    setObjectName("ProjectController");
+    setObjectName(QStringLiteral("ProjectController"));
 
     d->m_core = core;
     d->model = new ProjectModel();
@@ -494,22 +495,22 @@ void ProjectController::setupActions()
 
     QAction*action;
 
-    d->m_openProject = action = ac->addAction( "project_open" );
+    d->m_openProject = action = ac->addAction( QStringLiteral("project_open") );
     action->setText(i18nc( "@action", "Open / Import Project..." ) );
     action->setToolTip( i18nc( "@info:tooltip", "Open or import project" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Open an existing KDevelop 4 project or import "
                                                     "an existing Project into KDevelop 4. This entry "
-                                                    "allows to select a KDevelop4 project file or an "
-                                                    "existing directory to open it in KDevelop. "
+                                                    "allows one to select a KDevelop4 project file "
+                                                    "or an existing directory to open it in KDevelop. "
                                                     "When opening an existing directory that does "
                                                     "not yet have a KDevelop4 project file, the file "
                                                     "will be created." ) );
-    action->setIcon(QIcon::fromTheme("project-open"));
+    action->setIcon(QIcon::fromTheme(QStringLiteral("project-open")));
     connect(action, &QAction::triggered, this, [&] { openProject(); });
 
-    d->m_fetchProject = action = ac->addAction( "project_fetch" );
+    d->m_fetchProject = action = ac->addAction( QStringLiteral("project_fetch") );
     action->setText(i18nc( "@action", "Fetch Project..." ) );
-    action->setIcon( QIcon::fromTheme( "edit-download" ) );
+    action->setIcon( QIcon::fromTheme( QStringLiteral("edit-download") ) );
     action->setToolTip( i18nc( "@info:tooltip", "Fetch project" ) );
     action->setWhatsThis( i18nc( "@info:whatsthis", "Guides the user through the project fetch "
                                                     "and then imports it into KDevelop 4." ) );
@@ -523,39 +524,39 @@ void ProjectController::setupActions()
 //    action->setWhatsThis( i18n( "Closes the current project." ) );
 //    action->setEnabled( false );
 
-    d->m_closeProject = action = ac->addAction( "project_close" );
+    d->m_closeProject = action = ac->addAction( QStringLiteral("project_close") );
     connect( action, &QAction::triggered, this, [&] { d->closeSelectedProjects(); } );
     action->setText( i18nc( "@action", "Close Project(s)" ) );
-    action->setIcon( QIcon::fromTheme( "project-development-close" ) );
+    action->setIcon( QIcon::fromTheme( QStringLiteral("project-development-close") ) );
     action->setToolTip( i18nc( "@info:tooltip", "Closes all currently selected projects" ) );
     action->setEnabled( false );
 
-    d->m_openConfig = action = ac->addAction( "project_open_config" );
+    d->m_openConfig = action = ac->addAction( QStringLiteral("project_open_config") );
     connect( action, &QAction::triggered, this, [&] { d->openProjectConfig(); } );
     action->setText( i18n( "Open Configuration..." ) );
-    action->setIcon( QIcon::fromTheme("configure") );
+    action->setIcon( QIcon::fromTheme(QStringLiteral("configure")) );
     action->setEnabled( false );
 
-    action = ac->addAction( "commit_current_project" );
+    action = ac->addAction( QStringLiteral("commit_current_project") );
     connect( action, &QAction::triggered, this, &ProjectController::commitCurrentProject );
     action->setText( i18n( "Commit Current Project..." ) );
     action->setIconText( i18n( "Commit..." ) );
-    action->setIcon( QIcon::fromTheme("svn-commit") );
+    action->setIcon( QIcon::fromTheme(QStringLiteral("svn-commit")) );
     connect(d->m_core->uiControllerInternal()->defaultMainWindow(), &MainWindow::areaChanged,
             this, [&] (Sublime::Area* area) { d->areaChanged(area); });
-    d->m_core->uiControllerInternal()->area(0, "code")->addAction(action);
+    d->m_core->uiControllerInternal()->area(0, QStringLiteral("code"))->addAction(action);
 
     KSharedConfig * config = KSharedConfig::openConfig().data();
 //     KConfigGroup group = config->group( "General Options" );
 
     d->m_recentAction = KStandardAction::openRecent(this, SLOT(openProject(QUrl)), this);
-    ac->addAction( "project_open_recent", d->m_recentAction );
+    ac->addAction( QStringLiteral("project_open_recent"), d->m_recentAction );
     d->m_recentAction->setText( i18n( "Open Recent Project" ) );
     d->m_recentAction->setWhatsThis( i18nc( "@info:whatsthis", "Opens recently opened project." ) );
     d->m_recentAction->loadEntries( KConfigGroup(config, "RecentProjects") );
 
     QAction* openProjectForFileAction = new QAction( this );
-    ac->addAction("project_open_for_file", openProjectForFileAction);
+    ac->addAction(QStringLiteral("project_open_for_file"), openProjectForFileAction);
     openProjectForFileAction->setText(i18n("Open Project for Current File"));
     connect( openProjectForFileAction, &QAction::triggered, this, &ProjectController::openProjectForUrlSlot);
 }
@@ -578,9 +579,7 @@ void ProjectController::cleanup()
         buildSetModel()->storeToSession( Core::self()->activeSession() );
     }
 
-    foreach( IProject* project, d->m_projects ) {
-        closeProject( project );
-    }
+    closeAllProjects();
 }
 
 void ProjectController::initialize()
@@ -599,7 +598,7 @@ void ProjectController::initialize()
     loadSettings(false);
     d->dialog = new ProjectDialogProvider(d);
 
-    QDBusConnection::sessionBus().registerObject( "/org/kdevelop/ProjectController",
+    QDBusConnection::sessionBus().registerObject( QStringLiteral("/org/kdevelop/ProjectController"),
         this, QDBusConnection::ExportScriptableSlots );
 
     KSharedConfigPtr config = Core::self()->activeSession()->config();
@@ -655,7 +654,7 @@ void ProjectController::eventuallyOpenProjectFile(KIO::Job* _job, KIO::UDSEntryL
         if(!entry.isDir()) {
             QString name = entry.stringValue( KIO::UDSEntry::UDS_NAME );
 
-            if(name.endsWith(".kdev4")) {
+            if(name.endsWith(QLatin1String(".kdev4"))) {
                 //We have found a project-file, open it
                 openProject(Path(Path(job->url()), name).toUrl());
                 d->m_foundProjectFile = true;
@@ -887,22 +886,14 @@ void ProjectController::initializePluginCleanup(IProject* proj)
     connect(proj, &IProject::destroyed, this, [&] { d->unloadAllProjectPlugins(); });
 }
 
-void ProjectController::closeProject(IProject* proj_)
+void ProjectController::takeProject(IProject* proj)
 {
-    if (!proj_)
-    {
+    if (!proj) {
         return;
     }
 
     // loading might have failed
-    d->m_currentlyOpening.removeAll(proj_->projectFile().toUrl());
-
-    Project* proj = dynamic_cast<KDevelop::Project*>( proj_ );
-    if( !proj )
-    {
-        qWarning() << "Unknown Project subclass found!";
-        return;
-    }
+    d->m_currentlyOpening.removeAll(proj->projectFile().toUrl());
     d->m_projects.removeAll(proj);
     emit projectClosing(proj);
     //Core::self()->saveSettings();     // The project file is being closed.
@@ -911,7 +902,6 @@ void ProjectController::closeProject(IProject* proj_)
     unloadUnusedProjectPlugins(proj);
     closeAllOpenedFiles(proj);
     proj->close();
-    proj->deleteLater();                //be safe when deleting
     if (d->m_projects.isEmpty())
     {
         initializePluginCleanup(proj);
@@ -921,7 +911,19 @@ void ProjectController::closeProject(IProject* proj_)
         d->saveListOfOpenedProjects();
 
     emit projectClosed(proj);
-    return;
+}
+
+void ProjectController::closeProject(IProject* proj)
+{
+    takeProject(proj);
+    proj->deleteLater(); // be safe when deleting
+}
+
+void ProjectController::closeAllProjects()
+{
+    foreach (auto project, d->m_projects) {
+        closeProject(project);
+    }
 }
 
 void ProjectController::abortOpeningProject(IProject* proj)
@@ -968,7 +970,17 @@ void ProjectController::configureProject( IProject* project )
 
 void ProjectController::addProject(IProject* project)
 {
-    d->m_projects.append( project );
+    Q_ASSERT(project);
+    if (d->m_projects.contains(project)) {
+        qWarning() << "Project already tracked by this project controller:" << project;
+        return;
+    }
+
+    // fake-emit signals so listeners are aware of a new project being added
+    emit projectAboutToBeOpened(project);
+    project->setParent(this);
+    d->m_projects.append(project);
+    emit projectOpened(project);
 }
 
 QItemSelectionModel* ProjectController::projectSelectionModel()
@@ -1020,7 +1032,7 @@ QString ProjectController::prettyFilePath(const QUrl& url, FormattingOptions for
             prefixText = project->name() + ':';
         }
         QString relativePath = project->path().relativePath(parent);
-        if(relativePath.startsWith("./")) {
+        if(relativePath.startsWith(QLatin1String("./"))) {
             relativePath = relativePath.mid(2);
         }
         if (!relativePath.isEmpty()) {
