@@ -26,7 +26,7 @@ class ProjectInfoPage : public QWidget
 Q_OBJECT
 public:
     explicit ProjectInfoPage( QWidget* parent = 0 );
-    virtual ~ProjectInfoPage();
+    ~ProjectInfoPage() override;
     void setProjectName( const QString& );
     void setProjectManager( const QString& );
 signals:
