@@ -46,33 +46,33 @@ class LaunchConfigurationType;
 class KDEVPLATFORMSHELL_EXPORT RunController : public IRunController
 {
     Q_OBJECT
+    Q_CLASSINFO("D-Bus Interface", "org.kdevelop.RunController")
 
 public:
     explicit RunController(QObject *parent);
-    ~RunController();
+    ~RunController() override;
 
-    virtual void registerJob(KJob *job) override;
-    virtual void unregisterJob(KJob *job) override;
-    virtual QList<KJob*> currentJobs() const override;
+    void registerJob(KJob *job) override;
+    void unregisterJob(KJob *job) override;
+    QList<KJob*> currentJobs() const override;
 
     KJob* execute(const QString& launchMode, ILaunchConfiguration* launch) override;
-    LaunchConfiguration* defaultLaunch() const;
     QList<ILaunchMode*> launchModes() const override;
 
     /**
      * @copydoc IRunController::addLaunchMode
      */
-    virtual void addLaunchMode( ILaunchMode* mode ) override;
+    void addLaunchMode( ILaunchMode* mode ) override;
 
     /**
      * @copydoc IRunController::removeLaunchMode
      */
-    virtual void removeLaunchMode( ILaunchMode* mode ) override;
+    void removeLaunchMode( ILaunchMode* mode ) override;
 
     /**
      * @copydoc IRunController::launchModeForId()
      */
-    virtual KDevelop::ILaunchMode* launchModeForId(const QString& id) const override;
+    KDevelop::ILaunchMode* launchModeForId(const QString& id) const override;
 
     void initialize();
     void cleanup();
@@ -83,21 +83,21 @@ public:
     void removeLaunchConfiguration( LaunchConfiguration* l );
 
     QList<LaunchConfiguration*> launchConfigurationsInternal() const;
-    virtual QList<ILaunchConfiguration*> launchConfigurations() const override;
+    QList<ILaunchConfiguration*> launchConfigurations() const override;
     /**
      * @copydoc IRunController::launchConfigurationTypes()
      */
-    virtual QList<LaunchConfigurationType*> launchConfigurationTypes() const override;
+    QList<LaunchConfigurationType*> launchConfigurationTypes() const override;
 
     /**
      * @copydoc IRunController::addConfigurationType()
      */
-    virtual void addConfigurationType( LaunchConfigurationType* type ) override;
+    void addConfigurationType( LaunchConfigurationType* type ) override;
 
     /**
      * @copydoc IRunController::removeConfigurationType()
      */
-    virtual void removeConfigurationType( LaunchConfigurationType* type ) override;
+    void removeConfigurationType( LaunchConfigurationType* type ) override;
 
     /**
      * Find the launch configuration type for the given @p id.
@@ -105,24 +105,26 @@ public:
      */
     LaunchConfigurationType* launchConfigurationTypeForId( const QString& ) override;
 
-    virtual ILaunchConfiguration* createLaunchConfiguration ( LaunchConfigurationType* type,
+    ILaunchConfiguration* createLaunchConfiguration ( LaunchConfigurationType* type,
                                                               const QPair<QString,QString>& launcher,
                                                               IProject* project = 0,
                                                               const QString& name = QString() ) override;
 
-    virtual void executeDefaultLaunch(const QString& runMode) override;
 
     void setDefaultLaunch(ILaunchConfiguration* l);
+    LaunchConfiguration* defaultLaunch() const;
 
     ContextMenuExtension contextMenuExtension( KDevelop::Context* ctx );
 
 public Q_SLOTS:
-    virtual void stopAllProcesses() override;
+    Q_SCRIPTABLE void executeDefaultLaunch(const QString& runMode) override;
+
+    Q_SCRIPTABLE void stopAllProcesses() override;
 
 protected Q_SLOTS:
-    virtual void finished(KJob *job) override;
-    virtual void suspended(KJob *job) override;
-    virtual void resumed(KJob *job) override;
+    void finished(KJob *job) override;
+    void suspended(KJob *job) override;
+    void resumed(KJob *job) override;
 
 private Q_SLOTS:
     void slotRefreshProject(KDevelop::IProject* project);
@@ -138,6 +140,7 @@ private Q_SLOTS:
 private:
     void setupActions();
     void checkState();
+    void removeLaunchConfigurationInternal( LaunchConfiguration* l );
 
     Q_PRIVATE_SLOT(d, void configureLaunches())
     Q_PRIVATE_SLOT(d, void launchAs(int))
