@@ -46,7 +46,7 @@ class EditStyleDialog
 public:
     EditStyleDialog(KDevelop::ISourceFormatter* formatter, const QMimeType& mime,
                     const KDevelop::SourceFormatterStyle&, QWidget* parent = 0);
-    virtual ~EditStyleDialog();
+    ~EditStyleDialog() override;
 
     /** \return The string representing the style given by the \ref SettingsWidget.
      */
