@@ -18,7 +18,9 @@
  ***************************************************************************/
 #include "container.h"
 
+#include <QApplication>
 #include <QBoxLayout>
+#include <QClipboard>
 #include <QEvent>
 #include <QLabel>
 #include <QMap>
@@ -50,10 +52,13 @@ class ContainerTabBar : public QTabBar
     Q_OBJECT
 
 public:
-    ContainerTabBar(Container* container) : QTabBar(container), m_container(container) {
+    ContainerTabBar(Container* container)
+        : QTabBar(container), m_container(container)
+    {
+        installEventFilter(this);
     }
 
-    virtual bool event(QEvent* ev) override {
+    bool event(QEvent* ev) override {
         if(ev->type() == QEvent::ToolTip)
         {
             ev->accept();
@@ -70,7 +75,7 @@ public:
 
         return QTabBar::event(ev);
     }
-    virtual void mousePressEvent(QMouseEvent* event) override {
+    void mousePressEvent(QMouseEvent* event) override {
         if (event->button() == Qt::MidButton) {
             // just close on midbutton, drag can still be done with left mouse button
 
@@ -83,6 +88,25 @@ public:
         QTabBar::mousePressEvent(event);
     }
 
+    bool eventFilter(QObject* obj, QEvent* event) override
+    {
+        if (obj != this) {
+            return QObject::eventFilter(obj, event);
+        }
+
+        // TODO Qt6: Move to mouseDoubleClickEvent when fixme in qttabbar.cpp is resolved
+        // see "fixme Qt 6: move to mouseDoubleClickEvent(), here for BC reasons." in qtabbar.cpp
+        if (event->type() == QEvent::MouseButtonDblClick) {
+            // block tabBarDoubleClicked signals with RMB, see https://bugs.kde.org/show_bug.cgi?id=356016
+            auto mouseEvent = static_cast<const QMouseEvent*>(event);
+            if (mouseEvent->button() == Qt::MidButton) {
+                return true;
+            }
+        }
+
+        return QObject::eventFilter(obj, event);
+    }
+
 Q_SIGNALS:
     void newTabRequested();
 
@@ -144,6 +168,7 @@ struct ContainerPrivate {
 };
 
 class UnderlinedLabel: public KSqueezedTextLabel {
+Q_OBJECT
 public:
     UnderlinedLabel(QTabBar *tabBar, QWidget* parent = 0)
         :KSqueezedTextLabel(parent), m_tabBar(tabBar)
@@ -151,7 +176,7 @@ public:
     }
 
 protected:
-    virtual void paintEvent(QPaintEvent *ev) override
+    void paintEvent(QPaintEvent *ev) override
     {
         if (m_tabBar->isVisible() && m_tabBar->count() > 0)
         {
@@ -185,6 +210,7 @@ protected:
 
 
 class StatusLabel: public UnderlinedLabel {
+Q_OBJECT
 public:
     StatusLabel(QTabBar *tabBar, QWidget* parent = 0):
         UnderlinedLabel(tabBar, parent)
@@ -193,7 +219,7 @@ public:
         setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Fixed);
     }
 
-    virtual QSize minimumSizeHint() const override
+    QSize minimumSizeHint() const override
     {
         QRect rect = style()->itemTextRect(fontMetrics(), QRect(), Qt::AlignRight, true, i18n("Line: 00000 Col: 000"));
         rect.setHeight(m_tabBar->height());
@@ -218,7 +244,7 @@ Container::Container(QWidget *parent)
 
     d->documentListMenu = new QMenu(this);
     d->documentListButton = new QToolButton(this);
-    d->documentListButton->setIcon(QIcon::fromTheme("format-list-unordered"));
+    d->documentListButton->setIcon(QIcon::fromTheme(QStringLiteral("format-list-unordered")));
     d->documentListButton->setMenu(d->documentListMenu);
     d->documentListButton->setPopupMode(QToolButton::InstantPopup);
     d->documentListButton->setAutoRaise(true);
@@ -522,15 +548,19 @@ void Container::contextMenu( const QPoint& pos )
     emit tabContextMenuRequested(view, &menu);
 
     menu.addSeparator();
+    QAction* copyPathAction = nullptr;
     QAction* closeTabAction = nullptr;
     QAction* closeOtherTabsAction = nullptr;
     if (view) {
-        closeTabAction = menu.addAction(QIcon::fromTheme("document-close"),
+        copyPathAction = menu.addAction(QIcon::fromTheme(QStringLiteral("edit-copy")),
+                                        i18n("Copy Filename"));
+        menu.addSeparator();
+        closeTabAction = menu.addAction(QIcon::fromTheme(QStringLiteral("document-close")),
                                         i18n("Close File"));
-        closeOtherTabsAction = menu.addAction(QIcon::fromTheme("document-close"),
+        closeOtherTabsAction = menu.addAction(QIcon::fromTheme(QStringLiteral("document-close")),
                                               i18n("Close Other Files"));
     }
-    QAction* closeAllTabsAction = menu.addAction( QIcon::fromTheme("document-close"), i18n( "Close All Files" ) );
+    QAction* closeAllTabsAction = menu.addAction( QIcon::fromTheme(QStringLiteral("document-close")), i18n( "Close All Files" ) );
 
     QAction* triggered = menu.exec(senderWidget->mapToGlobal(pos));
 
@@ -559,6 +589,12 @@ void Container::contextMenu( const QPoint& pos )
             for ( int i = 0; i < count(); ++i ) {
                 requestClose(widget(i));
             }
+        } else if( triggered == copyPathAction ) {
+            auto view = viewForWidget( widget( currentTab ) );
+            auto urlDocument = qobject_cast<UrlDocument*>( view->document() );
+            if( urlDocument ) {
+                QApplication::clipboard()->setText( urlDocument->url().toString() );
+            }
         } // else the action was handled by someone else
     }
 }
