@@ -17,29 +17,31 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
 
-#ifndef MAIN_H
-#define MAIN_H
+#ifndef KDEVPLATFORM_MAIN_H
+#define KDEVPLATFORM_MAIN_H
 
 #include <QObject>
 #include <QAtomicInt>
+#include <QUrl>
+
 #include <language/duchain/topducontext.h>
 
 namespace KDevelop {
 class ParseJob;
 }
 
-class KCmdLineArgs;
+class QCommandLineParser;
 
 class Manager : public QObject {
     Q_OBJECT
     public:
-        Manager(KCmdLineArgs* args);
+        explicit Manager(QCommandLineParser* args);
         void addToBackgroundParser(QString path, KDevelop::TopDUContext::Features features);
-        QSet<KUrl> waiting();
+        QSet<QUrl> waiting();
     private:
-        QSet<KUrl> m_waiting;
+        QSet<QUrl> m_waiting;
         uint m_total;
-        KCmdLineArgs* m_args;
+        QCommandLineParser* m_args;
         QAtomicInt m_allFilesAdded;
 
     public slots:
@@ -47,6 +49,7 @@ class Manager : public QObject {
         void init();
         void updateReady(KDevelop::IndexedString url, KDevelop::ReferencedTopDUContext topContext);
         void finish();
+        void dump(const KDevelop::ReferencedTopDUContext& topContext);
 };
 
 #endif
