@@ -19,14 +19,12 @@ Boston, MA 02110-1301, USA.
 #include "environmentselectionwidget.h"
 #include "environmentgrouplist.h"
 #include "environmentselectionmodel.h"
-#include <ksettings/dispatcher.h>
-#include <kglobal.h>
+
+#include <QHBoxLayout>
+
+#include <KComboBox>
+
 #include <interfaces/icore.h>
-#include <kcomponentdata.h>
-#include <QtGui/QBoxLayout>
-#include <QtGui/QLayout>
-#include <KLocalizedString>
-#include <KDebug>
 
 namespace KDevelop
 {
@@ -65,6 +63,9 @@ EnvironmentSelectionWidget::EnvironmentSelectionWidget( QWidget *parent )
     layout()->setMargin( 0 );
 
     setCurrentProfile( QString() ); // select the default profile
+
+    connect(d->comboBox, &QComboBox::currentTextChanged,
+            this, &EnvironmentSelectionWidget::currentProfileChanged);
 }
 
 EnvironmentSelectionWidget::~EnvironmentSelectionWidget()
@@ -102,4 +103,3 @@ EnvironmentGroupList EnvironmentSelectionWidget::environment() const
 
 }
 
-#include "environmentselectionwidget.moc"
