@@ -36,7 +36,7 @@ class CommitView : public QTreeView
     Q_OBJECT
 public:
     explicit CommitView(QWidget *parent = 0);
-    ~CommitView() {};
+    ~CommitView() override {};
 //     void setLineHeight(int h) { lineHeight = h; }
     int getLineHeight(const QModelIndex & index) {return rowHeight(index);}
 private:
