@@ -24,9 +24,9 @@
 #include <QVariant>
 #include <QDateTime>
 #include <QList>
+#include <QLocale>
 
-#include <kglobal.h>
-#include <klocale.h>
+#include <KLocalizedString>
 
 #include "../vcsevent.h"
 #include "../vcsrevision.h"
@@ -44,12 +44,12 @@ public:
     QList<KDevelop::VcsEvent> m_events;
     KDevelop::IBasicVersionControl* m_iface;
     VcsRevision m_rev;
-    KUrl m_url;
+    QUrl m_url;
     bool done;
     bool fetching;
 };
 
-VcsEventModel::VcsEventModel( KDevelop::IBasicVersionControl* iface, const VcsRevision& rev, const KUrl& url, QObject* parent )
+VcsEventModel::VcsEventModel( KDevelop::IBasicVersionControl* iface, const VcsRevision& rev, const QUrl& url, QObject* parent )
     : QAbstractTableModel( parent ), d(new VcsEventModelPrivate)
 {
     d->m_iface = iface;
@@ -93,7 +93,7 @@ QVariant VcsEventModel::data( const QModelIndex& idx, int role ) const
         case AuthorColumn:
             return QVariant( ev.author() );
         case DateColumn:
-            return QVariant( KGlobal::locale()->formatDateTime( ev.date() ) );
+            return QVariant( QLocale().toString( ev.date() ) );
         default:
             break;
     }
@@ -150,8 +150,8 @@ void VcsEventModel::fetchMore(const QModelIndex& parent)
     Q_ASSERT(!parent.isValid());
     Q_UNUSED(parent);
     VcsJob* job = d->m_iface->log(d->m_url, d->m_rev, qMax(rowCount(), 100));
-    connect( this, SIGNAL(destroyed(QObject*)), job, SLOT(kill()) );
-    connect( job, SIGNAL(finished(KJob*)), SLOT(jobReceivedResults(KJob*)) );
+    connect(this, &VcsEventModel::destroyed, job, [&] { job->kill(); });
+    connect(job, &VcsJob::finished, this, &VcsEventModel::jobReceivedResults);
     ICore::self()->runController()->registerJob( job );
 }
 
@@ -165,9 +165,9 @@ void VcsEventModel::jobReceivedResults(KJob* job)
     QList<KDevelop::VcsEvent> newevents;
     foreach( const QVariant &v, l )
     {
-        if( qVariantCanConvert<KDevelop::VcsEvent>( v ) )
+        if( v.canConvert<KDevelop::VcsEvent>() )
         {
-            newevents << qVariantValue<KDevelop::VcsEvent>( v );
+            newevents << v.value<KDevelop::VcsEvent>();
         }
     }
     d->m_rev = newevents.last().revision();
@@ -181,4 +181,3 @@ void VcsEventModel::jobReceivedResults(KJob* job)
 
 }
 
-#include "vcseventmodel.moc"
