@@ -11,17 +11,8 @@
 
 #include "vcscommitdialog.h"
 
-#include <QtCore/QHash>
-#include <QtGui/QBrush>
-#include <QtCore/QRegExp>
-
-#include <KDE/KTextEdit>
-#include <KDE/KComboBox>
-#include <KDE/KLocale>
-#include <KDE/KDebug>
-#include <KDE/KColorScheme>
-#include <KDE/KMessageBox>
-#include <kparts/mainwindow.h>
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 #include <interfaces/icore.h>
 #include <interfaces/iprojectcontroller.h>
@@ -38,7 +29,6 @@
 #include "../models/vcsfilechangesmodel.h"
 
 #include "ui_vcscommitdialog.h"
-#include <KComponentData>
 #include <vcspluginhelper.h>
 
 namespace KDevelop
@@ -53,22 +43,26 @@ public:
 };
 
 VcsCommitDialog::VcsCommitDialog( IPatchSource *patchSource, QWidget *parent )
-    : KDialog( parent ), d(new VcsCommitDialogPrivate())
+    : QDialog( parent ), d(new VcsCommitDialogPrivate())
 {
-    d->ui.setupUi( mainWidget() );
+    auto mainWidget = new QWidget(this);
+    d->ui.setupUi(mainWidget);
+
     QWidget *customWidget = patchSource->customWidget();
     if( customWidget )
     {
         d->ui.gridLayout->addWidget( customWidget, 0, 0, 1, 2 );
     }
 
-    setButtons( KDialog::Ok | KDialog::Cancel );
+    auto okButton = d->ui.buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(d->ui.buttonBox, &QDialogButtonBox::accepted, this, &VcsCommitDialog::accept);
+    connect(d->ui.buttonBox, &QDialogButtonBox::rejected, this, &VcsCommitDialog::reject);
 
     d->m_patchSource = patchSource;
     d->m_model = new VcsFileChangesModel( this, true );
     d->ui.files->setModel( d->m_model );
-    connect(this, SIGNAL(okClicked()), SLOT(ok()) );
-    connect(this, SIGNAL(cancelClicked()), SLOT(cancel()) );
 }
 
 VcsCommitDialog::~VcsCommitDialog()
